###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file th.xml
# The source file version number was 1.136, generated on
# 2009/06/15 03:46:25.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::th;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "ก่อนเที่ยง", "หลังเที่ยง" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEEที่\ d\ MMMM\ G\ y";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\ MMMM\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "d\ MMM\ y";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "d\/M\/yyyy";
    sub date_format_short { return $date_format_short }
}

{
    my $datetime_format = "\{1\}\,\ \{0\}";
    sub datetime_format { return $datetime_format }
}

{
    my $day_format_abbreviated = [ "จ\.", "อ\.", "พ\.", "พฤ\.", "ศ\.", "ส\.", "อา\." ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "วันจันทร์", "วันอังคาร", "วันพุธ", "วันพฤหัสบดี", "วันศุกร์", "วันเสาร์", "วันอาทิตย์" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "จ", "อ", "พ", "พ", "ศ", "ส", "อ" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "ปีก่อน\ ค\.ศ\.", "ค\.ศ\." ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "ปีก่อนคริสต์ศักราช", "คริสต์ศักราช" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "ม\.ค\.", "ก\.พ\.", "มี\.ค\.", "เม\.ย\.", "พ\.ค\.", "มิ\.ย\.", "ก\.ค\.", "ส\.ค\.", "ก\.ย\.", "ต\.ค\.", "พ\.ย\.", "ธ\.ค\." ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "มกราคม", "กุมภาพันธ์", "มีนาคม", "เมษายน", "พฤษภาคม", "มิถุนายน", "กรกฎาคม", "สิงหาคม", "กันยายน", "ตุลาคม", "พฤศจิกายน", "ธันวาคม" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "ม\.ค\.", "ก\.พ\.", "มี\.ค\.", "เม\.ย\.", "พ\.ค\.", "มิ\.ย\.", "ก\.ค\.", "ส\.ค\.", "ก\.ย\.", "ต\.ค\.", "พ\.ย\.", "ธ\.ค\." ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "Q1", "Q2", "Q3", "Q4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "ไตรมาส\ 1", "ไตรมาส\ 2", "ไตรมาส\ 3", "ไตรมาส\ 4" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "H\ นาฬิกา\ m\ นาที\ ss\ วินาที\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "H\ นาฬิกา\ m\ นาที\ ss\ วินาที\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "H\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "H\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_EEEd = "EEE\ d";
    sub _format_for_EEEd { return $_format_for_EEEd }
}

{
    my $_format_for_HHmm = "HH\:mm";
    sub _format_for_HHmm { return $_format_for_HHmm }
}

{
    my $_format_for_HHmmss = "HH\:mm\:ss";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_Hm = "H\:mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "E\,\ d\/M";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "E\ d\ MMM";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "E\ d\ MMMM";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "d\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "d\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_Md = "d\/M";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_mmss = "mm\:ss";
    sub _format_for_mmss { return $_format_for_mmss }
}

{
    my $_format_for_ms = "mm\:ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "M\/yyyy";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "EEE\ d\/M\/yyyy";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "MMM\ y";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "EEE\ d\ MMM\ y";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "MMMM\ y";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yQ = "Q\ yyyy";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "QQQ\ y";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyyM = "M\/yyyy";
    sub _format_for_yyyyM { return $_format_for_yyyyM }
}

{
    my $_format_for_yyyyMMMM = "MMMM\ y";
    sub _format_for_yyyyMMMM { return $_format_for_yyyyMMMM }
}

{
    my $_available_formats =
        {
          "EEEd" => "EEE\ d",
          "HHmm" => "HH\:mm",
          "HHmmss" => "HH\:mm\:ss",
          "Hm" => "H\:mm",
          "M" => "L",
          "MEd" => "E\,\ d\/M",
          "MMM" => "LLL",
          "MMMEd" => "E\ d\ MMM",
          "MMMMEd" => "E\ d\ MMMM",
          "MMMMd" => "d\ MMMM",
          "MMMd" => "d\ MMM",
          "Md" => "d\/M",
          "d" => "d",
          "mmss" => "mm\:ss",
          "ms" => "mm\:ss",
          "y" => "y",
          "yM" => "M\/yyyy",
          "yMEd" => "EEE\ d\/M\/yyyy",
          "yMMM" => "MMM\ y",
          "yMMMEd" => "EEE\ d\ MMM\ y",
          "yMMMM" => "MMMM\ y",
          "yQ" => "Q\ yyyy",
          "yQQQ" => "QQQ\ y",
          "yyQ" => "Q\ yy",
          "yyyyM" => "M\/yyyy",
          "yyyyMMMM" => "MMMM\ y"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::th

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'th' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Thai.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  วันจันทร์
  วันอังคาร
  วันพุธ
  วันพฤหัสบดี
  วันศุกร์
  วันเสาร์
  วันอาทิตย์

=head3 Abbreviated (format)

  จ.
  อ.
  พ.
  พฤ.
  ศ.
  ส.
  อา.

=head3 Narrow (format)

  จ
  อ
  พ
  พ
  ศ
  ส
  อ

=head3 Wide (stand-alone)

  วันจันทร์
  วันอังคาร
  วันพุธ
  วันพฤหัสบดี
  วันศุกร์
  วันเสาร์
  วันอาทิตย์

=head3 Abbreviated (stand-alone)

  จ.
  อ.
  พ.
  พฤ.
  ศ.
  ส.
  อา.

=head3 Narrow (stand-alone)

  จ
  อ
  พ
  พ
  ศ
  ส
  อ

=head2 Months

=head3 Wide (format)

  มกราคม
  กุมภาพันธ์
  มีนาคม
  เมษายน
  พฤษภาคม
  มิถุนายน
  กรกฎาคม
  สิงหาคม
  กันยายน
  ตุลาคม
  พฤศจิกายน
  ธันวาคม

=head3 Abbreviated (format)

  ม.ค.
  ก.พ.
  มี.ค.
  เม.ย.
  พ.ค.
  มิ.ย.
  ก.ค.
  ส.ค.
  ก.ย.
  ต.ค.
  พ.ย.
  ธ.ค.

=head3 Narrow (format)

  ม.ค.
  ก.พ.
  มี.ค.
  เม.ย.
  พ.ค.
  มิ.ย.
  ก.ค.
  ส.ค.
  ก.ย.
  ต.ค.
  พ.ย.
  ธ.ค.

=head3 Wide (stand-alone)

  มกราคม
  กุมภาพันธ์
  มีนาคม
  เมษายน
  พฤษภาคม
  มิถุนายน
  กรกฎาคม
  สิงหาคม
  กันยายน
  ตุลาคม
  พฤศจิกายน
  ธันวาคม

=head3 Abbreviated (stand-alone)

  ม.ค.
  ก.พ.
  มี.ค.
  เม.ย.
  พ.ค.
  มิ.ย.
  ก.ค.
  ส.ค.
  ก.ย.
  ต.ค.
  พ.ย.
  ธ.ค.

=head3 Narrow (stand-alone)

  ม.ค.
  ก.พ.
  มี.ค.
  เม.ย.
  พ.ค.
  มิ.ย.
  ก.ค.
  ส.ค.
  ก.ย.
  ต.ค.
  พ.ย.
  ธ.ค.

=head2 Quarters

=head3 Wide (format)

  ไตรมาส 1
  ไตรมาส 2
  ไตรมาส 3
  ไตรมาส 4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  ไตรมาส 1
  ไตรมาส 2
  ไตรมาส 3
  ไตรมาส 4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  ปีก่อนคริสต์ศักราช
  คริสต์ศักราช

=head3 Abbreviated

  ปีก่อน ค.ศ.
  ค.ศ.

=head3 Narrow

  ปีก่อน ค.ศ.
  ค.ศ.

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = วันอังคารที่ 5 กุมภาพันธ์ ค.ศ. 2008
   1995-12-22T09:05:02 = วันศุกร์ที่ 22 ธันวาคม ค.ศ. 1995
  -0010-09-15T04:44:23 = วันเสาร์ที่ 15 กันยายน ปีก่อน ค.ศ. -10

=head3 Long

   2008-02-05T18:30:30 = 5 กุมภาพันธ์ 2008
   1995-12-22T09:05:02 = 22 ธันวาคม 1995
  -0010-09-15T04:44:23 = 15 กันยายน -10

=head3 Medium

   2008-02-05T18:30:30 = 5 ก.พ. 2008
   1995-12-22T09:05:02 = 22 ธ.ค. 1995
  -0010-09-15T04:44:23 = 15 ก.ย. -10

=head3 Short

   2008-02-05T18:30:30 = 5/2/2008
   1995-12-22T09:05:02 = 22/12/1995
  -0010-09-15T04:44:23 = 15/9/-010

=head3 Default

   2008-02-05T18:30:30 = 5 ก.พ. 2008
   1995-12-22T09:05:02 = 22 ธ.ค. 1995
  -0010-09-15T04:44:23 = 15 ก.ย. -10

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18 นาฬิกา 30 นาที 30 วินาที UTC
   1995-12-22T09:05:02 = 9 นาฬิกา 5 นาที 02 วินาที UTC
  -0010-09-15T04:44:23 = 4 นาฬิกา 44 นาที 23 วินาที UTC

=head3 Long

   2008-02-05T18:30:30 = 18 นาฬิกา 30 นาที 30 วินาที UTC
   1995-12-22T09:05:02 = 9 นาฬิกา 5 นาที 02 วินาที UTC
  -0010-09-15T04:44:23 = 4 นาฬิกา 44 นาที 23 วินาที UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = วันอังคารที่ 5 กุมภาพันธ์ ค.ศ. 2008, 18 นาฬิกา 30 นาที 30 วินาที UTC
   1995-12-22T09:05:02 = วันศุกร์ที่ 22 ธันวาคม ค.ศ. 1995, 9 นาฬิกา 5 นาที 02 วินาที UTC
  -0010-09-15T04:44:23 = วันเสาร์ที่ 15 กันยายน ปีก่อน ค.ศ. -10, 4 นาฬิกา 44 นาที 23 วินาที UTC

=head3 Long

   2008-02-05T18:30:30 = 5 กุมภาพันธ์ 2008, 18 นาฬิกา 30 นาที 30 วินาที UTC
   1995-12-22T09:05:02 = 22 ธันวาคม 1995, 9 นาฬิกา 5 นาที 02 วินาที UTC
  -0010-09-15T04:44:23 = 15 กันยายน -10, 4 นาฬิกา 44 นาที 23 วินาที UTC

=head3 Medium

   2008-02-05T18:30:30 = 5 ก.พ. 2008, 18:30:30
   1995-12-22T09:05:02 = 22 ธ.ค. 1995, 9:05:02
  -0010-09-15T04:44:23 = 15 ก.ย. -10, 4:44:23

=head3 Short

   2008-02-05T18:30:30 = 5/2/2008, 18:30
   1995-12-22T09:05:02 = 22/12/1995, 9:05
  -0010-09-15T04:44:23 = 15/9/-010, 4:44

=head3 Default

   2008-02-05T18:30:30 = 5 ก.พ. 2008, 18:30:30
   1995-12-22T09:05:02 = 22 ธ.ค. 1995, 9:05:02
  -0010-09-15T04:44:23 = 15 ก.ย. -10, 4:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (EEE d)

   2008-02-05T18:30:30 = อ. 5
   1995-12-22T09:05:02 = ศ. 22
  -0010-09-15T04:44:23 = ส. 15

=head3 HHmm (HH:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 HHmmss (HH:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 หลังเที่ยง
   1995-12-22T09:05:02 = 9:05 ก่อนเที่ยง
  -0010-09-15T04:44:23 = 4:44 ก่อนเที่ยง

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 หลังเที่ยง
   1995-12-22T09:05:02 = 9:05:02 ก่อนเที่ยง
  -0010-09-15T04:44:23 = 4:44:23 ก่อนเที่ยง

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (d/M)

   2008-02-05T18:30:30 = 5/2
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/9

=head3 MEd (E, d/M)

   2008-02-05T18:30:30 = อ., 5/2
   1995-12-22T09:05:02 = ศ., 22/12
  -0010-09-15T04:44:23 = ส., 15/9

=head3 MMM (LLL)

   2008-02-05T18:30:30 = ก.พ.
   1995-12-22T09:05:02 = ธ.ค.
  -0010-09-15T04:44:23 = ก.ย.

=head3 MMMd (d MMM)

   2008-02-05T18:30:30 = 5 ก.พ.
   1995-12-22T09:05:02 = 22 ธ.ค.
  -0010-09-15T04:44:23 = 15 ก.ย.

=head3 MMMEd (E d MMM)

   2008-02-05T18:30:30 = อ. 5 ก.พ.
   1995-12-22T09:05:02 = ศ. 22 ธ.ค.
  -0010-09-15T04:44:23 = ส. 15 ก.ย.

=head3 MMMMd (d MMMM)

   2008-02-05T18:30:30 = 5 กุมภาพันธ์
   1995-12-22T09:05:02 = 22 ธันวาคม
  -0010-09-15T04:44:23 = 15 กันยายน

=head3 MMMMEd (E d MMMM)

   2008-02-05T18:30:30 = อ. 5 กุมภาพันธ์
   1995-12-22T09:05:02 = ศ. 22 ธันวาคม
  -0010-09-15T04:44:23 = ส. 15 กันยายน

=head3 mmss (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (M/yyyy)

   2008-02-05T18:30:30 = 2/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 9/-010

=head3 yMEd (EEE d/M/yyyy)

   2008-02-05T18:30:30 = อ. 5/2/2008
   1995-12-22T09:05:02 = ศ. 22/12/1995
  -0010-09-15T04:44:23 = ส. 15/9/-010

=head3 yMMM (MMM y)

   2008-02-05T18:30:30 = ก.พ. 2008
   1995-12-22T09:05:02 = ธ.ค. 1995
  -0010-09-15T04:44:23 = ก.ย. -10

=head3 yMMMEd (EEE d MMM y)

   2008-02-05T18:30:30 = อ. 5 ก.พ. 2008
   1995-12-22T09:05:02 = ศ. 22 ธ.ค. 1995
  -0010-09-15T04:44:23 = ส. 15 ก.ย. -10

=head3 yMMMM (MMMM y)

   2008-02-05T18:30:30 = กุมภาพันธ์ 2008
   1995-12-22T09:05:02 = ธันวาคม 1995
  -0010-09-15T04:44:23 = กันยายน -10

=head3 yQ (Q yyyy)

   2008-02-05T18:30:30 = 1 2008
   1995-12-22T09:05:02 = 4 1995
  -0010-09-15T04:44:23 = 3 -010

=head3 yQQQ (QQQ y)

   2008-02-05T18:30:30 = Q1 2008
   1995-12-22T09:05:02 = Q4 1995
  -0010-09-15T04:44:23 = Q3 -10

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyyyM (M/yyyy)

   2008-02-05T18:30:30 = 2/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 9/-010

=head3 yyyyMMMM (MMMM y)

   2008-02-05T18:30:30 = กุมภาพันธ์ 2008
   1995-12-22T09:05:02 = ธันวาคม 1995
  -0010-09-15T04:44:23 = กันยายน -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

วันจันทร์


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
