###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file sv.xml
# The source file version number was 1.151, generated on
# 2009/06/15 03:46:23.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::sv;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "fm", "em" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\ d\ MMMM\ y";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\ MMMM\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "d\ MMM\ y";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "yyyy\-MM\-dd";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "mån", "tis", "ons", "tors", "fre", "lör", "sön" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "måndag", "tisdag", "onsdag", "torsdag", "fredag", "lördag", "söndag" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "M", "T", "O", "T", "F", "L", "S" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "f\.Kr\.", "e\.Kr\." ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "före\ Kristus", "efter\ Kristus" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "jan", "feb", "mar", "apr", "maj", "jun", "jul", "aug", "sep", "okt", "nov", "dec" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "januari", "februari", "mars", "april", "maj", "juni", "juli", "augusti", "september", "oktober", "november", "december" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "J", "F", "M", "A", "M", "J", "J", "A", "S", "O", "N", "D" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "K1", "K2", "K3", "K4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "1\:a\ kvartalet", "2\:a\ kvartalet", "3\:e\ kvartalet", "4\:e\ kvartalet" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "\'kl\'\.\ HH\.mm\.ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\.mm\.ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\.mm\.ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\.mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_HHmm = "HH\.mm";
    sub _format_for_HHmm { return $_format_for_HHmm }
}

{
    my $_format_for_HHmmss = "HH\.mm\.ss";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_Hm = "H\.mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "E\ d\/M";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "E\ d\ MMM";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEEEd = "EEE\ d\ MMMM";
    sub _format_for_MMMMEEEd { return $_format_for_MMMMEEEd }
}

{
    my $_format_for_MMMMEd = "E\ d\ MMMM";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "d\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "d\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_MMd = "d\/M";
    sub _format_for_MMd { return $_format_for_MMd }
}

{
    my $_format_for_MMdd = "dd\/MM";
    sub _format_for_MMdd { return $_format_for_MMdd }
}

{
    my $_format_for_Md = "d\/M";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_hhmm = "hh\.mm\ a";
    sub _format_for_hhmm { return $_format_for_hhmm }
}

{
    my $_format_for_hhmmss = "h\.mm\.ss\ a";
    sub _format_for_hhmmss { return $_format_for_hhmmss }
}

{
    my $_format_for_ms = "mm\.ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "yyyy\-MM";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "EEE\,\ yyyy\-MM\-dd";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "y\ MMM";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "EEE\ d\ MMM\ y";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "y\ MMMM";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yQ = "yyyy\ Q";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "y\ QQQ";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyMM = "yy\-MM";
    sub _format_for_yyMM { return $_format_for_yyMM }
}

{
    my $_format_for_yyMMM = "MMM\ \-yy";
    sub _format_for_yyMMM { return $_format_for_yyMMM }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyyMM = "yyyy\-MM";
    sub _format_for_yyyyMM { return $_format_for_yyyyMM }
}

{
    my $_format_for_yyyyMMM = "MMM\ y";
    sub _format_for_yyyyMMM { return $_format_for_yyyyMMM }
}

{
    my $_format_for_yyyyQQQQ = "QQQQ\ y";
    sub _format_for_yyyyQQQQ { return $_format_for_yyyyQQQQ }
}

{
    my $_available_formats =
        {
          "HHmm" => "HH\.mm",
          "HHmmss" => "HH\.mm\.ss",
          "Hm" => "H\.mm",
          "M" => "L",
          "MEd" => "E\ d\/M",
          "MMM" => "LLL",
          "MMMEd" => "E\ d\ MMM",
          "MMMMEEEd" => "EEE\ d\ MMMM",
          "MMMMEd" => "E\ d\ MMMM",
          "MMMMd" => "d\ MMMM",
          "MMMd" => "d\ MMM",
          "MMd" => "d\/M",
          "MMdd" => "dd\/MM",
          "Md" => "d\/M",
          "d" => "d",
          "hhmm" => "hh\.mm\ a",
          "hhmmss" => "h\.mm\.ss\ a",
          "ms" => "mm\.ss",
          "y" => "y",
          "yM" => "yyyy\-MM",
          "yMEd" => "EEE\,\ yyyy\-MM\-dd",
          "yMMM" => "y\ MMM",
          "yMMMEd" => "EEE\ d\ MMM\ y",
          "yMMMM" => "y\ MMMM",
          "yQ" => "yyyy\ Q",
          "yQQQ" => "y\ QQQ",
          "yyMM" => "yy\-MM",
          "yyMMM" => "MMM\ \-yy",
          "yyQ" => "Q\ yy",
          "yyyyMM" => "yyyy\-MM",
          "yyyyMMM" => "MMM\ y",
          "yyyyQQQQ" => "QQQQ\ y"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::sv

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'sv' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Swedish.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  måndag
  tisdag
  onsdag
  torsdag
  fredag
  lördag
  söndag

=head3 Abbreviated (format)

  mån
  tis
  ons
  tors
  fre
  lör
  sön

=head3 Narrow (format)

  M
  T
  O
  T
  F
  L
  S

=head3 Wide (stand-alone)

  måndag
  tisdag
  onsdag
  torsdag
  fredag
  lördag
  söndag

=head3 Abbreviated (stand-alone)

  mån
  tis
  ons
  tors
  fre
  lör
  sön

=head3 Narrow (stand-alone)

  M
  T
  O
  T
  F
  L
  S

=head2 Months

=head3 Wide (format)

  januari
  februari
  mars
  april
  maj
  juni
  juli
  augusti
  september
  oktober
  november
  december

=head3 Abbreviated (format)

  jan
  feb
  mar
  apr
  maj
  jun
  jul
  aug
  sep
  okt
  nov
  dec

=head3 Narrow (format)

  J
  F
  M
  A
  M
  J
  J
  A
  S
  O
  N
  D

=head3 Wide (stand-alone)

  januari
  februari
  mars
  april
  maj
  juni
  juli
  augusti
  september
  oktober
  november
  december

=head3 Abbreviated (stand-alone)

  jan
  feb
  mar
  apr
  maj
  jun
  jul
  aug
  sep
  okt
  nov
  dec

=head3 Narrow (stand-alone)

  J
  F
  M
  A
  M
  J
  J
  A
  S
  O
  N
  D

=head2 Quarters

=head3 Wide (format)

  1:a kvartalet
  2:a kvartalet
  3:e kvartalet
  4:e kvartalet

=head3 Abbreviated (format)

  K1
  K2
  K3
  K4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  1:a kvartalet
  2:a kvartalet
  3:e kvartalet
  4:e kvartalet

=head3 Abbreviated (stand-alone)

  K1
  K2
  K3
  K4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  före Kristus
  efter Kristus

=head3 Abbreviated

  f.Kr.
  e.Kr.

=head3 Narrow

  f.Kr.
  e.Kr.

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = tisdag 5 februari 2008
   1995-12-22T09:05:02 = fredag 22 december 1995
  -0010-09-15T04:44:23 = lördag 15 september -10

=head3 Long

   2008-02-05T18:30:30 = 5 februari 2008
   1995-12-22T09:05:02 = 22 december 1995
  -0010-09-15T04:44:23 = 15 september -10

=head3 Medium

   2008-02-05T18:30:30 = 5 feb 2008
   1995-12-22T09:05:02 = 22 dec 1995
  -0010-09-15T04:44:23 = 15 sep -10

=head3 Short

   2008-02-05T18:30:30 = 2008-02-05
   1995-12-22T09:05:02 = 1995-12-22
  -0010-09-15T04:44:23 = -010-09-15

=head3 Default

   2008-02-05T18:30:30 = 5 feb 2008
   1995-12-22T09:05:02 = 22 dec 1995
  -0010-09-15T04:44:23 = 15 sep -10

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = kl. 18.30.30 UTC
   1995-12-22T09:05:02 = kl. 09.05.02 UTC
  -0010-09-15T04:44:23 = kl. 04.44.23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18.30.30 UTC
   1995-12-22T09:05:02 = 09.05.02 UTC
  -0010-09-15T04:44:23 = 04.44.23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18.30.30
   1995-12-22T09:05:02 = 09.05.02
  -0010-09-15T04:44:23 = 04.44.23

=head3 Short

   2008-02-05T18:30:30 = 18.30
   1995-12-22T09:05:02 = 09.05
  -0010-09-15T04:44:23 = 04.44

=head3 Default

   2008-02-05T18:30:30 = 18.30.30
   1995-12-22T09:05:02 = 09.05.02
  -0010-09-15T04:44:23 = 04.44.23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = tisdag 5 februari 2008 kl. 18.30.30 UTC
   1995-12-22T09:05:02 = fredag 22 december 1995 kl. 09.05.02 UTC
  -0010-09-15T04:44:23 = lördag 15 september -10 kl. 04.44.23 UTC

=head3 Long

   2008-02-05T18:30:30 = 5 februari 2008 18.30.30 UTC
   1995-12-22T09:05:02 = 22 december 1995 09.05.02 UTC
  -0010-09-15T04:44:23 = 15 september -10 04.44.23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 5 feb 2008 18.30.30
   1995-12-22T09:05:02 = 22 dec 1995 09.05.02
  -0010-09-15T04:44:23 = 15 sep -10 04.44.23

=head3 Short

   2008-02-05T18:30:30 = 2008-02-05 18.30
   1995-12-22T09:05:02 = 1995-12-22 09.05
  -0010-09-15T04:44:23 = -010-09-15 04.44

=head3 Default

   2008-02-05T18:30:30 = 5 feb 2008 18.30.30
   1995-12-22T09:05:02 = 22 dec 1995 09.05.02
  -0010-09-15T04:44:23 = 15 sep -10 04.44.23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 tis
   1995-12-22T09:05:02 = 22 fre
  -0010-09-15T04:44:23 = 15 lör

=head3 HHmm (HH.mm)

   2008-02-05T18:30:30 = 18.30
   1995-12-22T09:05:02 = 09.05
  -0010-09-15T04:44:23 = 04.44

=head3 hhmm (hh.mm a)

   2008-02-05T18:30:30 = 06.30 em
   1995-12-22T09:05:02 = 09.05 fm
  -0010-09-15T04:44:23 = 04.44 fm

=head3 HHmmss (HH.mm.ss)

   2008-02-05T18:30:30 = 18.30.30
   1995-12-22T09:05:02 = 09.05.02
  -0010-09-15T04:44:23 = 04.44.23

=head3 hhmmss (h.mm.ss a)

   2008-02-05T18:30:30 = 6.30.30 em
   1995-12-22T09:05:02 = 9.05.02 fm
  -0010-09-15T04:44:23 = 4.44.23 fm

=head3 Hm (H.mm)

   2008-02-05T18:30:30 = 18.30
   1995-12-22T09:05:02 = 9.05
  -0010-09-15T04:44:23 = 4.44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 em
   1995-12-22T09:05:02 = 9:05 fm
  -0010-09-15T04:44:23 = 4:44 fm

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 em
   1995-12-22T09:05:02 = 9:05:02 fm
  -0010-09-15T04:44:23 = 4:44:23 fm

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (d/M)

   2008-02-05T18:30:30 = 5/2
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/9

=head3 MEd (E d/M)

   2008-02-05T18:30:30 = tis 5/2
   1995-12-22T09:05:02 = fre 22/12
  -0010-09-15T04:44:23 = lör 15/9

=head3 MMd (d/M)

   2008-02-05T18:30:30 = 5/2
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/9

=head3 MMdd (dd/MM)

   2008-02-05T18:30:30 = 05/02
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/09

=head3 MMM (LLL)

   2008-02-05T18:30:30 = feb
   1995-12-22T09:05:02 = dec
  -0010-09-15T04:44:23 = sep

=head3 MMMd (d MMM)

   2008-02-05T18:30:30 = 5 feb
   1995-12-22T09:05:02 = 22 dec
  -0010-09-15T04:44:23 = 15 sep

=head3 MMMEd (E d MMM)

   2008-02-05T18:30:30 = tis 5 feb
   1995-12-22T09:05:02 = fre 22 dec
  -0010-09-15T04:44:23 = lör 15 sep

=head3 MMMMd (d MMMM)

   2008-02-05T18:30:30 = 5 februari
   1995-12-22T09:05:02 = 22 december
  -0010-09-15T04:44:23 = 15 september

=head3 MMMMEd (E d MMMM)

   2008-02-05T18:30:30 = tis 5 februari
   1995-12-22T09:05:02 = fre 22 december
  -0010-09-15T04:44:23 = lör 15 september

=head3 MMMMEEEd (EEE d MMMM)

   2008-02-05T18:30:30 = tis 5 februari
   1995-12-22T09:05:02 = fre 22 december
  -0010-09-15T04:44:23 = lör 15 september

=head3 ms (mm.ss)

   2008-02-05T18:30:30 = 30.30
   1995-12-22T09:05:02 = 05.02
  -0010-09-15T04:44:23 = 44.23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (yyyy-MM)

   2008-02-05T18:30:30 = 2008-02
   1995-12-22T09:05:02 = 1995-12
  -0010-09-15T04:44:23 = -010-09

=head3 yMEd (EEE, yyyy-MM-dd)

   2008-02-05T18:30:30 = tis, 2008-02-05
   1995-12-22T09:05:02 = fre, 1995-12-22
  -0010-09-15T04:44:23 = lör, -010-09-15

=head3 yMMM (y MMM)

   2008-02-05T18:30:30 = 2008 feb
   1995-12-22T09:05:02 = 1995 dec
  -0010-09-15T04:44:23 = -10 sep

=head3 yMMMEd (EEE d MMM y)

   2008-02-05T18:30:30 = tis 5 feb 2008
   1995-12-22T09:05:02 = fre 22 dec 1995
  -0010-09-15T04:44:23 = lör 15 sep -10

=head3 yMMMM (y MMMM)

   2008-02-05T18:30:30 = 2008 februari
   1995-12-22T09:05:02 = 1995 december
  -0010-09-15T04:44:23 = -10 september

=head3 yQ (yyyy Q)

   2008-02-05T18:30:30 = 2008 1
   1995-12-22T09:05:02 = 1995 4
  -0010-09-15T04:44:23 = -010 3

=head3 yQQQ (y QQQ)

   2008-02-05T18:30:30 = 2008 K1
   1995-12-22T09:05:02 = 1995 K4
  -0010-09-15T04:44:23 = -10 K3

=head3 yyMM (yy-MM)

   2008-02-05T18:30:30 = 08-02
   1995-12-22T09:05:02 = 95-12
  -0010-09-15T04:44:23 = -10-09

=head3 yyMMM (MMM -yy)

   2008-02-05T18:30:30 = feb -08
   1995-12-22T09:05:02 = dec -95
  -0010-09-15T04:44:23 = sep --10

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyyyMM (yyyy-MM)

   2008-02-05T18:30:30 = 2008-02
   1995-12-22T09:05:02 = 1995-12
  -0010-09-15T04:44:23 = -010-09

=head3 yyyyMMM (MMM y)

   2008-02-05T18:30:30 = feb 2008
   1995-12-22T09:05:02 = dec 1995
  -0010-09-15T04:44:23 = sep -10

=head3 yyyyQQQQ (QQQQ y)

   2008-02-05T18:30:30 = 1:a kvartalet 2008
   1995-12-22T09:05:02 = 4:e kvartalet 1995
  -0010-09-15T04:44:23 = 3:e kvartalet -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

måndag


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
