###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file fur.xml
# The source file version number was 1.41, generated on
# 2009/06/15 20:34:50.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::fur;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "a\.", "p\." ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\ d\ \'di\'\ MMMM\ \'dal\'\ y";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\ \'di\'\ MMMM\ \'dal\'\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "dd\/MM\/yyyy";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "dd\/MM\/yy";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "lun", "mar", "mie", "joi", "vin", "sab", "dom" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "lunis", "martars", "miercus", "joibe", "vinars", "sabide", "domenie" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "L", "M", "M", "J", "V", "S", "D" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "pdC", "ddC" ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "pdC", "ddC" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "Zen", "Fev", "Mar", "Avr", "Mai", "Jug", "Lui", "Avo", "Set", "Otu", "Nov", "Dic" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "Zenâr", "Fevrâr", "Març", "Avrîl", "Mai", "Jugn", "Lui", "Avost", "Setembar", "Otubar", "Novembar", "Dicembar" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "Z", "F", "M", "A", "M", "J", "L", "A", "S", "O", "N", "D" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "T1", "T2", "T3", "T4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "Prin\ trimestri", "Secont\ trimestri", "Tierç\ trimestri", "Cuart\ trimestri" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "HH\:mm\:ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\:mm\:ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_EEEd = "d\ EEE";
    sub _format_for_EEEd { return $_format_for_EEEd }
}

{
    my $_format_for_Hm = "H\:mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "E\ d\/M";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "E\ d\ MMM";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "E\ d\ MMMM";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "d\ \'di\'\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "d\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_MMd = "d\/MM";
    sub _format_for_MMd { return $_format_for_MMd }
}

{
    my $_format_for_Md = "d\/M";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_ms = "mm\:ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "M\/yyyy";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "EEE\,\ d\/M\/yyyy";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "MMM\ y";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "EEE\ d\ MMM\ y";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "LLLL\ \'dal\'\ y";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yQ = "Q\ yyyy";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "QQQ\ y";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyMM = "MM\/yy";
    sub _format_for_yyMM { return $_format_for_yyMM }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyyMMMM = "MMMM\ y";
    sub _format_for_yyyyMMMM { return $_format_for_yyyyMMMM }
}

{
    my $_available_formats =
        {
          "EEEd" => "d\ EEE",
          "Hm" => "H\:mm",
          "M" => "L",
          "MEd" => "E\ d\/M",
          "MMM" => "LLL",
          "MMMEd" => "E\ d\ MMM",
          "MMMMEd" => "E\ d\ MMMM",
          "MMMMd" => "d\ \'di\'\ MMMM",
          "MMMd" => "d\ MMM",
          "MMd" => "d\/MM",
          "Md" => "d\/M",
          "d" => "d",
          "ms" => "mm\:ss",
          "y" => "y",
          "yM" => "M\/yyyy",
          "yMEd" => "EEE\,\ d\/M\/yyyy",
          "yMMM" => "MMM\ y",
          "yMMMEd" => "EEE\ d\ MMM\ y",
          "yMMMM" => "LLLL\ \'dal\'\ y",
          "yQ" => "Q\ yyyy",
          "yQQQ" => "QQQ\ y",
          "yyMM" => "MM\/yy",
          "yyQ" => "Q\ yy",
          "yyyyMMMM" => "MMMM\ y"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::fur

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'fur' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Friulian.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  lunis
  martars
  miercus
  joibe
  vinars
  sabide
  domenie

=head3 Abbreviated (format)

  lun
  mar
  mie
  joi
  vin
  sab
  dom

=head3 Narrow (format)

  L
  M
  M
  J
  V
  S
  D

=head3 Wide (stand-alone)

  lunis
  martars
  miercus
  joibe
  vinars
  sabide
  domenie

=head3 Abbreviated (stand-alone)

  lun
  mar
  mie
  joi
  vin
  sab
  dom

=head3 Narrow (stand-alone)

  L
  M
  M
  J
  V
  S
  D

=head2 Months

=head3 Wide (format)

  Zenâr
  Fevrâr
  Març
  Avrîl
  Mai
  Jugn
  Lui
  Avost
  Setembar
  Otubar
  Novembar
  Dicembar

=head3 Abbreviated (format)

  Zen
  Fev
  Mar
  Avr
  Mai
  Jug
  Lui
  Avo
  Set
  Otu
  Nov
  Dic

=head3 Narrow (format)

  Z
  F
  M
  A
  M
  J
  L
  A
  S
  O
  N
  D

=head3 Wide (stand-alone)

  Zenâr
  Fevrâr
  Març
  Avrîl
  Mai
  Jugn
  Lui
  Avost
  Setembar
  Otubar
  Novembar
  Dicembar

=head3 Abbreviated (stand-alone)

  Zen
  Fev
  Mar
  Avr
  Mai
  Jug
  Lui
  Avo
  Set
  Otu
  Nov
  Dic

=head3 Narrow (stand-alone)

  Z
  F
  M
  A
  M
  J
  L
  A
  S
  O
  N
  D

=head2 Quarters

=head3 Wide (format)

  Prin trimestri
  Secont trimestri
  Tierç trimestri
  Cuart trimestri

=head3 Abbreviated (format)

  T1
  T2
  T3
  T4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Prin trimestri
  Secont trimestri
  Tierç trimestri
  Cuart trimestri

=head3 Abbreviated (stand-alone)

  T1
  T2
  T3
  T4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  pdC
  ddC

=head3 Abbreviated

  pdC
  ddC

=head3 Narrow

  pdC
  ddC

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = martars 5 di Fevrâr dal 2008
   1995-12-22T09:05:02 = vinars 22 di Dicembar dal 1995
  -0010-09-15T04:44:23 = sabide 15 di Setembar dal -10

=head3 Long

   2008-02-05T18:30:30 = 5 di Fevrâr dal 2008
   1995-12-22T09:05:02 = 22 di Dicembar dal 1995
  -0010-09-15T04:44:23 = 15 di Setembar dal -10

=head3 Medium

   2008-02-05T18:30:30 = 05/02/2008
   1995-12-22T09:05:02 = 22/12/1995
  -0010-09-15T04:44:23 = 15/09/-010

=head3 Short

   2008-02-05T18:30:30 = 05/02/08
   1995-12-22T09:05:02 = 22/12/95
  -0010-09-15T04:44:23 = 15/09/-10

=head3 Default

   2008-02-05T18:30:30 = 05/02/2008
   1995-12-22T09:05:02 = 22/12/1995
  -0010-09-15T04:44:23 = 15/09/-010

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = martars 5 di Fevrâr dal 2008 18:30:30 UTC
   1995-12-22T09:05:02 = vinars 22 di Dicembar dal 1995 09:05:02 UTC
  -0010-09-15T04:44:23 = sabide 15 di Setembar dal -10 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 5 di Fevrâr dal 2008 18:30:30 UTC
   1995-12-22T09:05:02 = 22 di Dicembar dal 1995 09:05:02 UTC
  -0010-09-15T04:44:23 = 15 di Setembar dal -10 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 05/02/2008 18:30:30
   1995-12-22T09:05:02 = 22/12/1995 09:05:02
  -0010-09-15T04:44:23 = 15/09/-010 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 05/02/08 18:30
   1995-12-22T09:05:02 = 22/12/95 09:05
  -0010-09-15T04:44:23 = 15/09/-10 04:44

=head3 Default

   2008-02-05T18:30:30 = 05/02/2008 18:30:30
   1995-12-22T09:05:02 = 22/12/1995 09:05:02
  -0010-09-15T04:44:23 = 15/09/-010 04:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 mar
   1995-12-22T09:05:02 = 22 vin
  -0010-09-15T04:44:23 = 15 sab

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 p.
   1995-12-22T09:05:02 = 9:05 a.
  -0010-09-15T04:44:23 = 4:44 a.

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 p.
   1995-12-22T09:05:02 = 9:05:02 a.
  -0010-09-15T04:44:23 = 4:44:23 a.

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (d/M)

   2008-02-05T18:30:30 = 5/2
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/9

=head3 MEd (E d/M)

   2008-02-05T18:30:30 = mar 5/2
   1995-12-22T09:05:02 = vin 22/12
  -0010-09-15T04:44:23 = sab 15/9

=head3 MMd (d/MM)

   2008-02-05T18:30:30 = 5/02
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/09

=head3 MMM (LLL)

   2008-02-05T18:30:30 = Fev
   1995-12-22T09:05:02 = Dic
  -0010-09-15T04:44:23 = Set

=head3 MMMd (d MMM)

   2008-02-05T18:30:30 = 5 Fev
   1995-12-22T09:05:02 = 22 Dic
  -0010-09-15T04:44:23 = 15 Set

=head3 MMMEd (E d MMM)

   2008-02-05T18:30:30 = mar 5 Fev
   1995-12-22T09:05:02 = vin 22 Dic
  -0010-09-15T04:44:23 = sab 15 Set

=head3 MMMMd (d 'di' MMMM)

   2008-02-05T18:30:30 = 5 di Fevrâr
   1995-12-22T09:05:02 = 22 di Dicembar
  -0010-09-15T04:44:23 = 15 di Setembar

=head3 MMMMEd (E d MMMM)

   2008-02-05T18:30:30 = mar 5 Fevrâr
   1995-12-22T09:05:02 = vin 22 Dicembar
  -0010-09-15T04:44:23 = sab 15 Setembar

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (M/yyyy)

   2008-02-05T18:30:30 = 2/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 9/-010

=head3 yMEd (EEE, d/M/yyyy)

   2008-02-05T18:30:30 = mar, 5/2/2008
   1995-12-22T09:05:02 = vin, 22/12/1995
  -0010-09-15T04:44:23 = sab, 15/9/-010

=head3 yMMM (MMM y)

   2008-02-05T18:30:30 = Fev 2008
   1995-12-22T09:05:02 = Dic 1995
  -0010-09-15T04:44:23 = Set -10

=head3 yMMMEd (EEE d MMM y)

   2008-02-05T18:30:30 = mar 5 Fev 2008
   1995-12-22T09:05:02 = vin 22 Dic 1995
  -0010-09-15T04:44:23 = sab 15 Set -10

=head3 yMMMM (LLLL 'dal' y)

   2008-02-05T18:30:30 = Fevrâr dal 2008
   1995-12-22T09:05:02 = Dicembar dal 1995
  -0010-09-15T04:44:23 = Setembar dal -10

=head3 yQ (Q yyyy)

   2008-02-05T18:30:30 = 1 2008
   1995-12-22T09:05:02 = 4 1995
  -0010-09-15T04:44:23 = 3 -010

=head3 yQQQ (QQQ y)

   2008-02-05T18:30:30 = T1 2008
   1995-12-22T09:05:02 = T4 1995
  -0010-09-15T04:44:23 = T3 -10

=head3 yyMM (MM/yy)

   2008-02-05T18:30:30 = 02/08
   1995-12-22T09:05:02 = 12/95
  -0010-09-15T04:44:23 = 09/-10

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyyyMMMM (MMMM y)

   2008-02-05T18:30:30 = Fevrâr 2008
   1995-12-22T09:05:02 = Dicembar 1995
  -0010-09-15T04:44:23 = Setembar -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

lunis


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
