###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file he.xml
# The source file version number was 1.126, generated on
# 2009/06/15 03:46:24.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::he;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "לפנה\"צ", "אחה\"צ" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\,\ d\ בMMMM\ y";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\ בMMMM\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "dd\/MM\/yyyy";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "dd\/MM\/yy";
    sub date_format_short { return $date_format_short }
}

{
    my $datetime_format = "\{1\}\ \{0\}";
    sub datetime_format { return $datetime_format }
}

{
    my $day_format_abbreviated = [ "יום\ ב\'", "יום\ ג\'", "יום\ ד\'", "יום\ ה\'", "יום\ ו\'", "שבת", "יום\ א\'" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "יום\ שני", "יום\ שלישי", "יום\ רביעי", "יום\ חמישי", "יום\ שישי", "יום\ שבת", "יום\ ראשון" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "ב", "ג", "ד", "ה", "ו", "ש", "א" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "לפנה״ס", "לסה״נ" ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "לפני\ הספירה", "לספירה" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "ינו", "פבר", "מרס", "אפר", "מאי", "יונ", "יול", "אוג", "ספט", "אוק", "נוב", "דצמ" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_format_abbreviated() }

{
    my $month_format_wide = [ "ינואר", "פברואר", "מרס", "אפריל", "מאי", "יוני", "יולי", "אוגוסט", "ספטמבר", "אוקטובר", "נובמבר", "דצמבר" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }


sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "רבעון\ 1", "רבעון\ 2", "רבעון\ 3", "רבעון\ 4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "רבעון\ 1", "רבעון\ 2", "רבעון\ 3", "רבעון\ 4" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "HH\:mm\:ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\:mm\:ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_Ed = "E\ d";
    sub _format_for_Ed { return $_format_for_Ed }
}

{
    my $_format_for_H = "H";
    sub _format_for_H { return $_format_for_H }
}

{
    my $_format_for_HHmm = "HH\:mm";
    sub _format_for_HHmm { return $_format_for_HHmm }
}

{
    my $_format_for_HHmmss = "HH\:mm\:ss";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_Hm = "H\:mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "E\,\ M\-d";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "E\ d\ MMM";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "E\ MMMM\ d";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "d\ בMMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "MMM\ d";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_MMdd = "dd\/MM";
    sub _format_for_MMdd { return $_format_for_MMdd }
}

{
    my $_format_for_Md = "d\/M";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_mmss = "mm\:ss";
    sub _format_for_mmss { return $_format_for_mmss }
}

{
    my $_format_for_ms = "mm\:ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "M\.yyyy";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "EEE\,\ d\.M\.yyyy";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "y\ MMM";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "EEE\,\ y\ MMM\ d";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "MMMM\ y";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yQ = "yyyy\ Q";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "y\ QQQ";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyMM = "MM\/yy";
    sub _format_for_yyMM { return $_format_for_yyMM }
}

{
    my $_format_for_yyMMM = "MMM\ yy";
    sub _format_for_yyMMM { return $_format_for_yyMMM }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyy = "y";
    sub _format_for_yyyy { return $_format_for_yyyy }
}

{
    my $_format_for_yyyyMM = "MM\/yyyy";
    sub _format_for_yyyyMM { return $_format_for_yyyyMM }
}

{
    my $_format_for_yyyyMMMM = "MMMM\ y";
    sub _format_for_yyyyMMMM { return $_format_for_yyyyMMMM }
}

{
    my $_available_formats =
        {
          "Ed" => "E\ d",
          "H" => "H",
          "HHmm" => "HH\:mm",
          "HHmmss" => "HH\:mm\:ss",
          "Hm" => "H\:mm",
          "M" => "L",
          "MEd" => "E\,\ M\-d",
          "MMM" => "LLL",
          "MMMEd" => "E\ d\ MMM",
          "MMMMEd" => "E\ MMMM\ d",
          "MMMMd" => "d\ בMMMM",
          "MMMd" => "MMM\ d",
          "MMdd" => "dd\/MM",
          "Md" => "d\/M",
          "d" => "d",
          "mmss" => "mm\:ss",
          "ms" => "mm\:ss",
          "y" => "y",
          "yM" => "M\.yyyy",
          "yMEd" => "EEE\,\ d\.M\.yyyy",
          "yMMM" => "y\ MMM",
          "yMMMEd" => "EEE\,\ y\ MMM\ d",
          "yMMMM" => "MMMM\ y",
          "yQ" => "yyyy\ Q",
          "yQQQ" => "y\ QQQ",
          "yyMM" => "MM\/yy",
          "yyMMM" => "MMM\ yy",
          "yyQ" => "Q\ yy",
          "yyyy" => "y",
          "yyyyMM" => "MM\/yyyy",
          "yyyyMMMM" => "MMMM\ y"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::he

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'he' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Hebrew.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  יום שני
  יום שלישי
  יום רביעי
  יום חמישי
  יום שישי
  יום שבת
  יום ראשון

=head3 Abbreviated (format)

  יום ב'
  יום ג'
  יום ד'
  יום ה'
  יום ו'
  שבת
  יום א'

=head3 Narrow (format)

  ב
  ג
  ד
  ה
  ו
  ש
  א

=head3 Wide (stand-alone)

  יום שני
  יום שלישי
  יום רביעי
  יום חמישי
  יום שישי
  יום שבת
  יום ראשון

=head3 Abbreviated (stand-alone)

  יום ב'
  יום ג'
  יום ד'
  יום ה'
  יום ו'
  שבת
  יום א'

=head3 Narrow (stand-alone)

  ב
  ג
  ד
  ה
  ו
  ש
  א

=head2 Months

=head3 Wide (format)

  ינואר
  פברואר
  מרס
  אפריל
  מאי
  יוני
  יולי
  אוגוסט
  ספטמבר
  אוקטובר
  נובמבר
  דצמבר

=head3 Abbreviated (format)

  ינו
  פבר
  מרס
  אפר
  מאי
  יונ
  יול
  אוג
  ספט
  אוק
  נוב
  דצמ

=head3 Narrow (format)

  ינו
  פבר
  מרס
  אפר
  מאי
  יונ
  יול
  אוג
  ספט
  אוק
  נוב
  דצמ

=head3 Wide (stand-alone)

  ינואר
  פברואר
  מרס
  אפריל
  מאי
  יוני
  יולי
  אוגוסט
  ספטמבר
  אוקטובר
  נובמבר
  דצמבר

=head3 Abbreviated (stand-alone)

  ינו
  פבר
  מרס
  אפר
  מאי
  יונ
  יול
  אוג
  ספט
  אוק
  נוב
  דצמ

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  רבעון 1
  רבעון 2
  רבעון 3
  רבעון 4

=head3 Abbreviated (format)

  רבעון 1
  רבעון 2
  רבעון 3
  רבעון 4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  רבעון 1
  רבעון 2
  רבעון 3
  רבעון 4

=head3 Abbreviated (stand-alone)

  רבעון 1
  רבעון 2
  רבעון 3
  רבעון 4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  לפני הספירה
  לספירה

=head3 Abbreviated

  לפנה״ס
  לסה״נ

=head3 Narrow

  לפנה״ס
  לסה״נ

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = יום שלישי, 5 בפברואר 2008
   1995-12-22T09:05:02 = יום שישי, 22 בדצמבר 1995
  -0010-09-15T04:44:23 = יום שבת, 15 בספטמבר -10

=head3 Long

   2008-02-05T18:30:30 = 5 בפברואר 2008
   1995-12-22T09:05:02 = 22 בדצמבר 1995
  -0010-09-15T04:44:23 = 15 בספטמבר -10

=head3 Medium

   2008-02-05T18:30:30 = 05/02/2008
   1995-12-22T09:05:02 = 22/12/1995
  -0010-09-15T04:44:23 = 15/09/-010

=head3 Short

   2008-02-05T18:30:30 = 05/02/08
   1995-12-22T09:05:02 = 22/12/95
  -0010-09-15T04:44:23 = 15/09/-10

=head3 Default

   2008-02-05T18:30:30 = 05/02/2008
   1995-12-22T09:05:02 = 22/12/1995
  -0010-09-15T04:44:23 = 15/09/-010

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = יום שלישי, 5 בפברואר 2008 18:30:30 UTC
   1995-12-22T09:05:02 = יום שישי, 22 בדצמבר 1995 09:05:02 UTC
  -0010-09-15T04:44:23 = יום שבת, 15 בספטמבר -10 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 5 בפברואר 2008 18:30:30 UTC
   1995-12-22T09:05:02 = 22 בדצמבר 1995 09:05:02 UTC
  -0010-09-15T04:44:23 = 15 בספטמבר -10 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 05/02/2008 18:30:30
   1995-12-22T09:05:02 = 22/12/1995 09:05:02
  -0010-09-15T04:44:23 = 15/09/-010 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 05/02/08 18:30
   1995-12-22T09:05:02 = 22/12/95 09:05
  -0010-09-15T04:44:23 = 15/09/-10 04:44

=head3 Default

   2008-02-05T18:30:30 = 05/02/2008 18:30:30
   1995-12-22T09:05:02 = 22/12/1995 09:05:02
  -0010-09-15T04:44:23 = 15/09/-010 04:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 Ed (E d)

   2008-02-05T18:30:30 = יום ג' 5
   1995-12-22T09:05:02 = יום ו' 22
  -0010-09-15T04:44:23 = שבת 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 יום ג'
   1995-12-22T09:05:02 = 22 יום ו'
  -0010-09-15T04:44:23 = 15 שבת

=head3 H (H)

   2008-02-05T18:30:30 = 18
   1995-12-22T09:05:02 = 9
  -0010-09-15T04:44:23 = 4

=head3 HHmm (HH:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 HHmmss (HH:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 אחה"צ
   1995-12-22T09:05:02 = 9:05 לפנה"צ
  -0010-09-15T04:44:23 = 4:44 לפנה"צ

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 אחה"צ
   1995-12-22T09:05:02 = 9:05:02 לפנה"צ
  -0010-09-15T04:44:23 = 4:44:23 לפנה"צ

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (d/M)

   2008-02-05T18:30:30 = 5/2
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/9

=head3 MEd (E, M-d)

   2008-02-05T18:30:30 = יום ג', 2-5
   1995-12-22T09:05:02 = יום ו', 12-22
  -0010-09-15T04:44:23 = שבת, 9-15

=head3 MMdd (dd/MM)

   2008-02-05T18:30:30 = 05/02
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/09

=head3 MMM (LLL)

   2008-02-05T18:30:30 = פבר
   1995-12-22T09:05:02 = דצמ
  -0010-09-15T04:44:23 = ספט

=head3 MMMd (MMM d)

   2008-02-05T18:30:30 = פבר 5
   1995-12-22T09:05:02 = דצמ 22
  -0010-09-15T04:44:23 = ספט 15

=head3 MMMEd (E d MMM)

   2008-02-05T18:30:30 = יום ג' 5 פבר
   1995-12-22T09:05:02 = יום ו' 22 דצמ
  -0010-09-15T04:44:23 = שבת 15 ספט

=head3 MMMMd (d בMMMM)

   2008-02-05T18:30:30 = 5 בפברואר
   1995-12-22T09:05:02 = 22 בדצמבר
  -0010-09-15T04:44:23 = 15 בספטמבר

=head3 MMMMEd (E MMMM d)

   2008-02-05T18:30:30 = יום ג' פברואר 5
   1995-12-22T09:05:02 = יום ו' דצמבר 22
  -0010-09-15T04:44:23 = שבת ספטמבר 15

=head3 mmss (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (M.yyyy)

   2008-02-05T18:30:30 = 2.2008
   1995-12-22T09:05:02 = 12.1995
  -0010-09-15T04:44:23 = 9.-010

=head3 yMEd (EEE, d.M.yyyy)

   2008-02-05T18:30:30 = יום ג', 5.2.2008
   1995-12-22T09:05:02 = יום ו', 22.12.1995
  -0010-09-15T04:44:23 = שבת, 15.9.-010

=head3 yMMM (y MMM)

   2008-02-05T18:30:30 = 2008 פבר
   1995-12-22T09:05:02 = 1995 דצמ
  -0010-09-15T04:44:23 = -10 ספט

=head3 yMMMEd (EEE, y MMM d)

   2008-02-05T18:30:30 = יום ג', 2008 פבר 5
   1995-12-22T09:05:02 = יום ו', 1995 דצמ 22
  -0010-09-15T04:44:23 = שבת, -10 ספט 15

=head3 yMMMM (MMMM y)

   2008-02-05T18:30:30 = פברואר 2008
   1995-12-22T09:05:02 = דצמבר 1995
  -0010-09-15T04:44:23 = ספטמבר -10

=head3 yQ (yyyy Q)

   2008-02-05T18:30:30 = 2008 1
   1995-12-22T09:05:02 = 1995 4
  -0010-09-15T04:44:23 = -010 3

=head3 yQQQ (y QQQ)

   2008-02-05T18:30:30 = 2008 רבעון 1
   1995-12-22T09:05:02 = 1995 רבעון 4
  -0010-09-15T04:44:23 = -10 רבעון 3

=head3 yyMM (MM/yy)

   2008-02-05T18:30:30 = 02/08
   1995-12-22T09:05:02 = 12/95
  -0010-09-15T04:44:23 = 09/-10

=head3 yyMMM (MMM yy)

   2008-02-05T18:30:30 = פבר 08
   1995-12-22T09:05:02 = דצמ 95
  -0010-09-15T04:44:23 = ספט -10

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyyy (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yyyyMM (MM/yyyy)

   2008-02-05T18:30:30 = 02/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 09/-010

=head3 yyyyMMMM (MMMM y)

   2008-02-05T18:30:30 = פברואר 2008
   1995-12-22T09:05:02 = דצמבר 1995
  -0010-09-15T04:44:23 = ספטמבר -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

יום שני


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
