###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file ko.xml
# The source file version number was 1.140, generated on
# 2009/06/15 17:12:26.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ko;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "오전", "오후" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "y년\ M월\ d일\ EEEE";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "y년\ M월\ d일";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "yyyy\.\ M\.\ d\.";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "yy\.\ M\.\ d\.";
    sub date_format_short { return $date_format_short }
}

{
    my $datetime_format = "\{1\}\{0\}";
    sub datetime_format { return $datetime_format }
}

{
    my $day_format_abbreviated = [ "월", "화", "수", "목", "금", "토", "일" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "월요일", "화요일", "수요일", "목요일", "금요일", "토요일", "일요일" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "월", "화", "수", "목", "금", "토", "일" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "기원전", "서기" ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "서력기원전", "서력기원" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}


sub month_format_abbreviated { $_[0]->month_format_wide() }


sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "1월", "2월", "3월", "4월", "5월", "6월", "7월", "8월", "9월", "10월", "11월", "12월" ];
    sub month_format_wide { return $month_format_wide }
}
{
    my $month_stand_alone_narrow = [ "1월", "2월", "3월", "4월", "5월", "6월", "7월", "8월", "9월", "10월", "11월", "12월" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "1분기", "2분기", "3분기", "4분기" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "제\ 1\/4분기", "제\ 2\/4분기", "제\ 3\/4분기", "제\ 4\/4분기" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "a\ hh시\ mm분\ ss초\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "a\ hh시\ mm분\ ss초\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "a\ h\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "a\ h\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_EEEd = "d일\ EEE";
    sub _format_for_EEEd { return $_format_for_EEEd }
}

{
    my $_format_for_Ed = "d일\ \(E\)";
    sub _format_for_Ed { return $_format_for_Ed }
}

{
    my $_format_for_HHmm = "HH\:mm";
    sub _format_for_HHmm { return $_format_for_HHmm }
}

{
    my $_format_for_HHmmss = "HH\:mm\:ss";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_Hm = "H\:mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_Hms = "H시\ m분\ s초";
    sub _format_for_Hms { return $_format_for_Hms }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "M\.\ d\.\ \(E\)";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "MMM\ d일\ \(E\)";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "MMMM\ d일\ \(E\)";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "MMMM\ d일";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "MMM\ d일";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_MMdd = "MM\.\ dd";
    sub _format_for_MMdd { return $_format_for_MMdd }
}

{
    my $_format_for_Md = "M\.\ d\.";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_mmss = "mm\:ss";
    sub _format_for_mmss { return $_format_for_mmss }
}

{
    my $_format_for_ms = "mm\:ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "yyyy\.\ M\.";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "yyyy\.\ M\.\ d\.\ EEE";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "y년\ MMM";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "y년\ MMM\ d일\ EEE";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "y년\ MMMM";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yMMMd = "y년\ MMM\ d일";
    sub _format_for_yMMMd { return $_format_for_yMMMd }
}

{
    my $_format_for_yQ = "y년\ Q분기";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "y년\ QQQ";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyMM = "YY\.\ M\.";
    sub _format_for_yyMM { return $_format_for_yyMM }
}

{
    my $_format_for_yyMMM = "yy년\ MMM";
    sub _format_for_yyMMM { return $_format_for_yyMMM }
}

{
    my $_format_for_yyQ = "yy년\ Q분기";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyyMM = "yyyy\.\ MM";
    sub _format_for_yyyyMM { return $_format_for_yyyyMM }
}

{
    my $_available_formats =
        {
          "EEEd" => "d일\ EEE",
          "Ed" => "d일\ \(E\)",
          "HHmm" => "HH\:mm",
          "HHmmss" => "HH\:mm\:ss",
          "Hm" => "H\:mm",
          "Hms" => "H시\ m분\ s초",
          "M" => "L",
          "MEd" => "M\.\ d\.\ \(E\)",
          "MMM" => "LLL",
          "MMMEd" => "MMM\ d일\ \(E\)",
          "MMMMEd" => "MMMM\ d일\ \(E\)",
          "MMMMd" => "MMMM\ d일",
          "MMMd" => "MMM\ d일",
          "MMdd" => "MM\.\ dd",
          "Md" => "M\.\ d\.",
          "d" => "d",
          "mmss" => "mm\:ss",
          "ms" => "mm\:ss",
          "y" => "y",
          "yM" => "yyyy\.\ M\.",
          "yMEd" => "yyyy\.\ M\.\ d\.\ EEE",
          "yMMM" => "y년\ MMM",
          "yMMMEd" => "y년\ MMM\ d일\ EEE",
          "yMMMM" => "y년\ MMMM",
          "yMMMd" => "y년\ MMM\ d일",
          "yQ" => "y년\ Q분기",
          "yQQQ" => "y년\ QQQ",
          "yyMM" => "YY\.\ M\.",
          "yyMMM" => "yy년\ MMM",
          "yyQ" => "yy년\ Q분기",
          "yyyyMM" => "yyyy\.\ MM"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::ko

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'ko' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Korean.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  월요일
  화요일
  수요일
  목요일
  금요일
  토요일
  일요일

=head3 Abbreviated (format)

  월
  화
  수
  목
  금
  토
  일

=head3 Narrow (format)

  월
  화
  수
  목
  금
  토
  일

=head3 Wide (stand-alone)

  월요일
  화요일
  수요일
  목요일
  금요일
  토요일
  일요일

=head3 Abbreviated (stand-alone)

  월
  화
  수
  목
  금
  토
  일

=head3 Narrow (stand-alone)

  월
  화
  수
  목
  금
  토
  일

=head2 Months

=head3 Wide (format)

  1월
  2월
  3월
  4월
  5월
  6월
  7월
  8월
  9월
  10월
  11월
  12월

=head3 Abbreviated (format)

  1월
  2월
  3월
  4월
  5월
  6월
  7월
  8월
  9월
  10월
  11월
  12월

=head3 Narrow (format)

  1월
  2월
  3월
  4월
  5월
  6월
  7월
  8월
  9월
  10월
  11월
  12월

=head3 Wide (stand-alone)

  1월
  2월
  3월
  4월
  5월
  6월
  7월
  8월
  9월
  10월
  11월
  12월

=head3 Abbreviated (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Narrow (stand-alone)

  1월
  2월
  3월
  4월
  5월
  6월
  7월
  8월
  9월
  10월
  11월
  12월

=head2 Quarters

=head3 Wide (format)

  제 1/4분기
  제 2/4분기
  제 3/4분기
  제 4/4분기

=head3 Abbreviated (format)

  1분기
  2분기
  3분기
  4분기

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  제 1/4분기
  제 2/4분기
  제 3/4분기
  제 4/4분기

=head3 Abbreviated (stand-alone)

  1분기
  2분기
  3분기
  4분기

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  서력기원전
  서력기원

=head3 Abbreviated

  기원전
  서기

=head3 Narrow

  기원전
  서기

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = 2008년 2월 5일 화요일
   1995-12-22T09:05:02 = 1995년 12월 22일 금요일
  -0010-09-15T04:44:23 = -10년 9월 15일 토요일

=head3 Long

   2008-02-05T18:30:30 = 2008년 2월 5일
   1995-12-22T09:05:02 = 1995년 12월 22일
  -0010-09-15T04:44:23 = -10년 9월 15일

=head3 Medium

   2008-02-05T18:30:30 = 2008. 2. 5.
   1995-12-22T09:05:02 = 1995. 12. 22.
  -0010-09-15T04:44:23 = -010. 9. 15.

=head3 Short

   2008-02-05T18:30:30 = 08. 2. 5.
   1995-12-22T09:05:02 = 95. 12. 22.
  -0010-09-15T04:44:23 = -10. 9. 15.

=head3 Default

   2008-02-05T18:30:30 = 2008. 2. 5.
   1995-12-22T09:05:02 = 1995. 12. 22.
  -0010-09-15T04:44:23 = -010. 9. 15.

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 오후 06시 30분 30초 UTC
   1995-12-22T09:05:02 = 오전 09시 05분 02초 UTC
  -0010-09-15T04:44:23 = 오전 04시 44분 23초 UTC

=head3 Long

   2008-02-05T18:30:30 = 오후 06시 30분 30초 UTC
   1995-12-22T09:05:02 = 오전 09시 05분 02초 UTC
  -0010-09-15T04:44:23 = 오전 04시 44분 23초 UTC

=head3 Medium

   2008-02-05T18:30:30 = 오후 6:30:30
   1995-12-22T09:05:02 = 오전 9:05:02
  -0010-09-15T04:44:23 = 오전 4:44:23

=head3 Short

   2008-02-05T18:30:30 = 오후 6:30
   1995-12-22T09:05:02 = 오전 9:05
  -0010-09-15T04:44:23 = 오전 4:44

=head3 Default

   2008-02-05T18:30:30 = 오후 6:30:30
   1995-12-22T09:05:02 = 오전 9:05:02
  -0010-09-15T04:44:23 = 오전 4:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = 2008년 2월 5일 화요일오후 06시 30분 30초 UTC
   1995-12-22T09:05:02 = 1995년 12월 22일 금요일오전 09시 05분 02초 UTC
  -0010-09-15T04:44:23 = -10년 9월 15일 토요일오전 04시 44분 23초 UTC

=head3 Long

   2008-02-05T18:30:30 = 2008년 2월 5일오후 06시 30분 30초 UTC
   1995-12-22T09:05:02 = 1995년 12월 22일오전 09시 05분 02초 UTC
  -0010-09-15T04:44:23 = -10년 9월 15일오전 04시 44분 23초 UTC

=head3 Medium

   2008-02-05T18:30:30 = 2008. 2. 5.오후 6:30:30
   1995-12-22T09:05:02 = 1995. 12. 22.오전 9:05:02
  -0010-09-15T04:44:23 = -010. 9. 15.오전 4:44:23

=head3 Short

   2008-02-05T18:30:30 = 08. 2. 5.오후 6:30
   1995-12-22T09:05:02 = 95. 12. 22.오전 9:05
  -0010-09-15T04:44:23 = -10. 9. 15.오전 4:44

=head3 Default

   2008-02-05T18:30:30 = 2008. 2. 5.오후 6:30:30
   1995-12-22T09:05:02 = 1995. 12. 22.오전 9:05:02
  -0010-09-15T04:44:23 = -010. 9. 15.오전 4:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 Ed (d일 (E))

   2008-02-05T18:30:30 = 5일 (화)
   1995-12-22T09:05:02 = 22일 (금)
  -0010-09-15T04:44:23 = 15일 (토)

=head3 EEEd (d일 EEE)

   2008-02-05T18:30:30 = 5일 화
   1995-12-22T09:05:02 = 22일 금
  -0010-09-15T04:44:23 = 15일 토

=head3 HHmm (HH:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 HHmmss (HH:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 오후
   1995-12-22T09:05:02 = 9:05 오전
  -0010-09-15T04:44:23 = 4:44 오전

=head3 Hms (H시 m분 s초)

   2008-02-05T18:30:30 = 18시 30분 30초
   1995-12-22T09:05:02 = 9시 5분 2초
  -0010-09-15T04:44:23 = 4시 44분 23초

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 오후
   1995-12-22T09:05:02 = 9:05:02 오전
  -0010-09-15T04:44:23 = 4:44:23 오전

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (M. d.)

   2008-02-05T18:30:30 = 2. 5.
   1995-12-22T09:05:02 = 12. 22.
  -0010-09-15T04:44:23 = 9. 15.

=head3 MEd (M. d. (E))

   2008-02-05T18:30:30 = 2. 5. (화)
   1995-12-22T09:05:02 = 12. 22. (금)
  -0010-09-15T04:44:23 = 9. 15. (토)

=head3 MMdd (MM. dd)

   2008-02-05T18:30:30 = 02. 05
   1995-12-22T09:05:02 = 12. 22
  -0010-09-15T04:44:23 = 09. 15

=head3 MMM (LLL)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 MMMd (MMM d일)

   2008-02-05T18:30:30 = 2월 5일
   1995-12-22T09:05:02 = 12월 22일
  -0010-09-15T04:44:23 = 9월 15일

=head3 MMMEd (MMM d일 (E))

   2008-02-05T18:30:30 = 2월 5일 (화)
   1995-12-22T09:05:02 = 12월 22일 (금)
  -0010-09-15T04:44:23 = 9월 15일 (토)

=head3 MMMMd (MMMM d일)

   2008-02-05T18:30:30 = 2월 5일
   1995-12-22T09:05:02 = 12월 22일
  -0010-09-15T04:44:23 = 9월 15일

=head3 MMMMEd (MMMM d일 (E))

   2008-02-05T18:30:30 = 2월 5일 (화)
   1995-12-22T09:05:02 = 12월 22일 (금)
  -0010-09-15T04:44:23 = 9월 15일 (토)

=head3 mmss (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (yyyy. M.)

   2008-02-05T18:30:30 = 2008. 2.
   1995-12-22T09:05:02 = 1995. 12.
  -0010-09-15T04:44:23 = -010. 9.

=head3 yMEd (yyyy. M. d. EEE)

   2008-02-05T18:30:30 = 2008. 2. 5. 화
   1995-12-22T09:05:02 = 1995. 12. 22. 금
  -0010-09-15T04:44:23 = -010. 9. 15. 토

=head3 yMMM (y년 MMM)

   2008-02-05T18:30:30 = 2008년 2월
   1995-12-22T09:05:02 = 1995년 12월
  -0010-09-15T04:44:23 = -10년 9월

=head3 yMMMd (y년 MMM d일)

   2008-02-05T18:30:30 = 2008년 2월 5일
   1995-12-22T09:05:02 = 1995년 12월 22일
  -0010-09-15T04:44:23 = -10년 9월 15일

=head3 yMMMEd (y년 MMM d일 EEE)

   2008-02-05T18:30:30 = 2008년 2월 5일 화
   1995-12-22T09:05:02 = 1995년 12월 22일 금
  -0010-09-15T04:44:23 = -10년 9월 15일 토

=head3 yMMMM (y년 MMMM)

   2008-02-05T18:30:30 = 2008년 2월
   1995-12-22T09:05:02 = 1995년 12월
  -0010-09-15T04:44:23 = -10년 9월

=head3 yQ (y년 Q분기)

   2008-02-05T18:30:30 = 2008년 1분기
   1995-12-22T09:05:02 = 1995년 4분기
  -0010-09-15T04:44:23 = -10년 3분기

=head3 yQQQ (y년 QQQ)

   2008-02-05T18:30:30 = 2008년 1분기
   1995-12-22T09:05:02 = 1995년 4분기
  -0010-09-15T04:44:23 = -10년 3분기

=head3 yyMM (YY. M.)

   2008-02-05T18:30:30 = 2008. 2.
   1995-12-22T09:05:02 = 1995. 12.
  -0010-09-15T04:44:23 = -10. 9.

=head3 yyMMM (yy년 MMM)

   2008-02-05T18:30:30 = 08년 2월
   1995-12-22T09:05:02 = 95년 12월
  -0010-09-15T04:44:23 = -10년 9월

=head3 yyQ (yy년 Q분기)

   2008-02-05T18:30:30 = 08년 1분기
   1995-12-22T09:05:02 = 95년 4분기
  -0010-09-15T04:44:23 = -10년 3분기

=head3 yyyyMM (yyyy. MM)

   2008-02-05T18:30:30 = 2008. 02
   1995-12-22T09:05:02 = 1995. 12
  -0010-09-15T04:44:23 = -010. 09

=head2 Miscellaneous

=head3 Prefers 24 hour time?

No

=head3 Local first day of the week

월요일


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
