###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file uk.xml
# The source file version number was 1.131, generated on
# 2009/06/15 03:46:23.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::uk;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "дп", "пп" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\,\ d\ MMMM\ y\ \'р\'\.";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\ MMMM\ y\ \'р\'\.";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "d\ MMM\ y";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "dd\.MM\.yy";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "Пн", "Вт", "Ср", "Чт", "Пт", "Сб", "Нд" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "Понеділок", "Вівторок", "Середа", "Четвер", "Пʼятниця", "Субота", "Неділя" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "П", "В", "С", "Ч", "П", "С", "Н" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "до\ н\.е\.", "н\.е\." ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "до\ нашої\ ери", "нашої\ ери" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "січ\.", "лют\.", "бер\.", "квіт\.", "трав\.", "черв\.", "лип\.", "серп\.", "вер\.", "жовт\.", "лист\.", "груд\." ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "січня", "лютого", "березня", "квітня", "травня", "червня", "липня", "серпня", "вересня", "жовтня", "листопада", "грудня" ];
    sub month_format_wide { return $month_format_wide }
}
{
    my $month_stand_alone_abbreviated = [ "Січ", "Лют", "Бер", "Кві", "Тра", "Чер", "Лип", "Сер", "Вер", "Жов", "Лис", "Гру" ];
    sub month_stand_alone_abbreviated { return $month_stand_alone_abbreviated }
}
{
    my $month_stand_alone_narrow = [ "С", "Л", "Б", "К", "Т", "Ч", "Л", "С", "В", "Ж", "Л", "Г" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}
{
    my $month_stand_alone_wide = [ "Січень", "Лютий", "Березень", "Квітень", "Травень", "Червень", "Липень", "Серпень", "Вересень", "Жовтень", "Листопад", "Грудень" ];
    sub month_stand_alone_wide { return $month_stand_alone_wide }
}
{
    my $quarter_format_abbreviated = [ "I\ кв\.", "II\ кв\.", "III\ кв\.", "IV\ кв\." ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "I\ квартал", "II\ квартал", "III\ квартал", "IV\ квартал" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "HH\:mm\:ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\:mm\:ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_HHmm = "HH\:mm";
    sub _format_for_HHmm { return $_format_for_HHmm }
}

{
    my $_format_for_HHmmss = "HH\:mm\:ss";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_Hm = "H\:mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "E\,\ d\ MMM";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "E\,\ d\ MMMM";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "d\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "d\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_MMdd = "dd\.MM";
    sub _format_for_MMdd { return $_format_for_MMdd }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_mmss = "mm\:ss";
    sub _format_for_mmss { return $_format_for_mmss }
}

{
    my $_format_for_ms = "mm\:ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yMMM = "LLL\ y";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "EEE\,\ d\ MMM\ y";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "LLLL\ y";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yyMM = "MM\.yy";
    sub _format_for_yyMM { return $_format_for_yyMM }
}

{
    my $_format_for_yyMMM = "LLL\ yy";
    sub _format_for_yyMMM { return $_format_for_yyMMM }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyyMMMM = "LLLL\ y";
    sub _format_for_yyyyMMMM { return $_format_for_yyyyMMMM }
}

{
    my $_format_for_yyyyQQQQ = "QQQQ\ y\ \'р\'\.";
    sub _format_for_yyyyQQQQ { return $_format_for_yyyyQQQQ }
}

{
    my $_available_formats =
        {
          "HHmm" => "HH\:mm",
          "HHmmss" => "HH\:mm\:ss",
          "Hm" => "H\:mm",
          "MMM" => "LLL",
          "MMMEd" => "E\,\ d\ MMM",
          "MMMMEd" => "E\,\ d\ MMMM",
          "MMMMd" => "d\ MMMM",
          "MMMd" => "d\ MMM",
          "MMdd" => "dd\.MM",
          "d" => "d",
          "mmss" => "mm\:ss",
          "ms" => "mm\:ss",
          "y" => "y",
          "yMMM" => "LLL\ y",
          "yMMMEd" => "EEE\,\ d\ MMM\ y",
          "yMMMM" => "LLLL\ y",
          "yyMM" => "MM\.yy",
          "yyMMM" => "LLL\ yy",
          "yyQ" => "Q\ yy",
          "yyyyMMMM" => "LLLL\ y",
          "yyyyQQQQ" => "QQQQ\ y\ \'р\'\."
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::uk

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'uk' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Ukrainian.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Понеділок
  Вівторок
  Середа
  Четвер
  Пʼятниця
  Субота
  Неділя

=head3 Abbreviated (format)

  Пн
  Вт
  Ср
  Чт
  Пт
  Сб
  Нд

=head3 Narrow (format)

  П
  В
  С
  Ч
  П
  С
  Н

=head3 Wide (stand-alone)

  Понеділок
  Вівторок
  Середа
  Четвер
  Пʼятниця
  Субота
  Неділя

=head3 Abbreviated (stand-alone)

  Пн
  Вт
  Ср
  Чт
  Пт
  Сб
  Нд

=head3 Narrow (stand-alone)

  П
  В
  С
  Ч
  П
  С
  Н

=head2 Months

=head3 Wide (format)

  січня
  лютого
  березня
  квітня
  травня
  червня
  липня
  серпня
  вересня
  жовтня
  листопада
  грудня

=head3 Abbreviated (format)

  січ.
  лют.
  бер.
  квіт.
  трав.
  черв.
  лип.
  серп.
  вер.
  жовт.
  лист.
  груд.

=head3 Narrow (format)

  С
  Л
  Б
  К
  Т
  Ч
  Л
  С
  В
  Ж
  Л
  Г

=head3 Wide (stand-alone)

  Січень
  Лютий
  Березень
  Квітень
  Травень
  Червень
  Липень
  Серпень
  Вересень
  Жовтень
  Листопад
  Грудень

=head3 Abbreviated (stand-alone)

  Січ
  Лют
  Бер
  Кві
  Тра
  Чер
  Лип
  Сер
  Вер
  Жов
  Лис
  Гру

=head3 Narrow (stand-alone)

  С
  Л
  Б
  К
  Т
  Ч
  Л
  С
  В
  Ж
  Л
  Г

=head2 Quarters

=head3 Wide (format)

  I квартал
  II квартал
  III квартал
  IV квартал

=head3 Abbreviated (format)

  I кв.
  II кв.
  III кв.
  IV кв.

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  I квартал
  II квартал
  III квартал
  IV квартал

=head3 Abbreviated (stand-alone)

  I кв.
  II кв.
  III кв.
  IV кв.

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  до нашої ери
  нашої ери

=head3 Abbreviated

  до н.е.
  н.е.

=head3 Narrow

  до н.е.
  н.е.

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = Вівторок, 5 лютого 2008 р.
   1995-12-22T09:05:02 = Пʼятниця, 22 грудня 1995 р.
  -0010-09-15T04:44:23 = Субота, 15 вересня -10 р.

=head3 Long

   2008-02-05T18:30:30 = 5 лютого 2008 р.
   1995-12-22T09:05:02 = 22 грудня 1995 р.
  -0010-09-15T04:44:23 = 15 вересня -10 р.

=head3 Medium

   2008-02-05T18:30:30 = 5 лют. 2008
   1995-12-22T09:05:02 = 22 груд. 1995
  -0010-09-15T04:44:23 = 15 вер. -10

=head3 Short

   2008-02-05T18:30:30 = 05.02.08
   1995-12-22T09:05:02 = 22.12.95
  -0010-09-15T04:44:23 = 15.09.-10

=head3 Default

   2008-02-05T18:30:30 = 5 лют. 2008
   1995-12-22T09:05:02 = 22 груд. 1995
  -0010-09-15T04:44:23 = 15 вер. -10

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = Вівторок, 5 лютого 2008 р. 18:30:30 UTC
   1995-12-22T09:05:02 = Пʼятниця, 22 грудня 1995 р. 09:05:02 UTC
  -0010-09-15T04:44:23 = Субота, 15 вересня -10 р. 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 5 лютого 2008 р. 18:30:30 UTC
   1995-12-22T09:05:02 = 22 грудня 1995 р. 09:05:02 UTC
  -0010-09-15T04:44:23 = 15 вересня -10 р. 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 5 лют. 2008 18:30:30
   1995-12-22T09:05:02 = 22 груд. 1995 09:05:02
  -0010-09-15T04:44:23 = 15 вер. -10 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 05.02.08 18:30
   1995-12-22T09:05:02 = 22.12.95 09:05
  -0010-09-15T04:44:23 = 15.09.-10 04:44

=head3 Default

   2008-02-05T18:30:30 = 5 лют. 2008 18:30:30
   1995-12-22T09:05:02 = 22 груд. 1995 09:05:02
  -0010-09-15T04:44:23 = 15 вер. -10 04:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 Вт
   1995-12-22T09:05:02 = 22 Пт
  -0010-09-15T04:44:23 = 15 Сб

=head3 HHmm (HH:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 HHmmss (HH:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 пп
   1995-12-22T09:05:02 = 9:05 дп
  -0010-09-15T04:44:23 = 4:44 дп

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 пп
   1995-12-22T09:05:02 = 9:05:02 дп
  -0010-09-15T04:44:23 = 4:44:23 дп

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (M-d)

   2008-02-05T18:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-09-15T04:44:23 = 9-15

=head3 MEd (E, M-d)

   2008-02-05T18:30:30 = Вт, 2-5
   1995-12-22T09:05:02 = Пт, 12-22
  -0010-09-15T04:44:23 = Сб, 9-15

=head3 MMdd (dd.MM)

   2008-02-05T18:30:30 = 05.02
   1995-12-22T09:05:02 = 22.12
  -0010-09-15T04:44:23 = 15.09

=head3 MMM (LLL)

   2008-02-05T18:30:30 = Лют
   1995-12-22T09:05:02 = Гру
  -0010-09-15T04:44:23 = Вер

=head3 MMMd (d MMM)

   2008-02-05T18:30:30 = 5 лют.
   1995-12-22T09:05:02 = 22 груд.
  -0010-09-15T04:44:23 = 15 вер.

=head3 MMMEd (E, d MMM)

   2008-02-05T18:30:30 = Вт, 5 лют.
   1995-12-22T09:05:02 = Пт, 22 груд.
  -0010-09-15T04:44:23 = Сб, 15 вер.

=head3 MMMMd (d MMMM)

   2008-02-05T18:30:30 = 5 лютого
   1995-12-22T09:05:02 = 22 грудня
  -0010-09-15T04:44:23 = 15 вересня

=head3 MMMMEd (E, d MMMM)

   2008-02-05T18:30:30 = Вт, 5 лютого
   1995-12-22T09:05:02 = Пт, 22 грудня
  -0010-09-15T04:44:23 = Сб, 15 вересня

=head3 mmss (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (y-M)

   2008-02-05T18:30:30 = 2008-2
   1995-12-22T09:05:02 = 1995-12
  -0010-09-15T04:44:23 = -10-9

=head3 yMEd (EEE, y-M-d)

   2008-02-05T18:30:30 = Вт, 2008-2-5
   1995-12-22T09:05:02 = Пт, 1995-12-22
  -0010-09-15T04:44:23 = Сб, -10-9-15

=head3 yMMM (LLL y)

   2008-02-05T18:30:30 = Лют 2008
   1995-12-22T09:05:02 = Гру 1995
  -0010-09-15T04:44:23 = Вер -10

=head3 yMMMEd (EEE, d MMM y)

   2008-02-05T18:30:30 = Вт, 5 лют. 2008
   1995-12-22T09:05:02 = Пт, 22 груд. 1995
  -0010-09-15T04:44:23 = Сб, 15 вер. -10

=head3 yMMMM (LLLL y)

   2008-02-05T18:30:30 = Лютий 2008
   1995-12-22T09:05:02 = Грудень 1995
  -0010-09-15T04:44:23 = Вересень -10

=head3 yQ (y Q)

   2008-02-05T18:30:30 = 2008 1
   1995-12-22T09:05:02 = 1995 4
  -0010-09-15T04:44:23 = -10 3

=head3 yQQQ (y QQQ)

   2008-02-05T18:30:30 = 2008 I кв.
   1995-12-22T09:05:02 = 1995 IV кв.
  -0010-09-15T04:44:23 = -10 III кв.

=head3 yyMM (MM.yy)

   2008-02-05T18:30:30 = 02.08
   1995-12-22T09:05:02 = 12.95
  -0010-09-15T04:44:23 = 09.-10

=head3 yyMMM (LLL yy)

   2008-02-05T18:30:30 = Лют 08
   1995-12-22T09:05:02 = Гру 95
  -0010-09-15T04:44:23 = Вер -10

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyyyMMMM (LLLL y)

   2008-02-05T18:30:30 = Лютий 2008
   1995-12-22T09:05:02 = Грудень 1995
  -0010-09-15T04:44:23 = Вересень -10

=head3 yyyyQQQQ (QQQQ y 'р'.)

   2008-02-05T18:30:30 = I квартал 2008 р.
   1995-12-22T09:05:02 = IV квартал 1995 р.
  -0010-09-15T04:44:23 = III квартал -10 р.

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

Понеділок


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
