###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file tr.xml
# The source file version number was 1.126, generated on
# 2009/06/15 03:46:23.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::tr;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "AM", "PM" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "dd\ MMMM\ y\ EEEE";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "dd\ MMMM\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "dd\ MMM\ y";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "dd\.MM\.yyyy";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "Pzt", "Sal", "Çar", "Per", "Cum", "Cmt", "Paz" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "Pazartesi", "Salı", "Çarşamba", "Perşembe", "Cuma", "Cumartesi", "Pazar" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "P", "S", "Ç", "P", "C", "C", "P" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "MÖ", "MS" ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "Milattan\ Önce", "Milattan\ Sonra" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "Oca", "Şub", "Mar", "Nis", "May", "Haz", "Tem", "Ağu", "Eyl", "Eki", "Kas", "Ara" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "Ocak", "Şubat", "Mart", "Nisan", "Mayıs", "Haziran", "Temmuz", "Ağustos", "Eylül", "Ekim", "Kasım", "Aralık" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "O", "Ş", "M", "N", "M", "H", "T", "A", "E", "E", "K", "A" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "Ç1", "Ç2", "Ç3", "Ç4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "1\.\ çeyrek", "2\.\ çeyrek", "3\.\ çeyrek", "4\.\ çeyrek" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "HH\:mm\:ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\:mm\:ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_EEEd = "d\ EEE";
    sub _format_for_EEEd { return $_format_for_EEEd }
}

{
    my $_format_for_Ed = "d\ E";
    sub _format_for_Ed { return $_format_for_Ed }
}

{
    my $_format_for_H = "H";
    sub _format_for_H { return $_format_for_H }
}

{
    my $_format_for_HHmm = "HH\:mm";
    sub _format_for_HHmm { return $_format_for_HHmm }
}

{
    my $_format_for_HHmmss = "HH\:mm\:ss";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_Hm = "HH\:mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "dd\/MM\ E";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "dd\ MMM\ E";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "dd\ MMMM\ E";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "dd\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "dd\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_Md = "dd\/MM";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_hhmm = "hh\:mm\ a";
    sub _format_for_hhmm { return $_format_for_hhmm }
}

{
    my $_format_for_hhmmss = "hh\:mm\:ss\ a";
    sub _format_for_hhmmss { return $_format_for_hhmmss }
}

{
    my $_format_for_mmss = "mm\:ss";
    sub _format_for_mmss { return $_format_for_mmss }
}

{
    my $_format_for_ms = "mm\:ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "M\/yyyy";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "dd\.MM\.yyyy\ EEE";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "MMM\ y";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "dd\ MMM\ y\ EEE";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "MMMM\ y";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yQ = "Q\ yyyy";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "QQQ\ y";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyMM = "MM\/yy";
    sub _format_for_yyMM { return $_format_for_yyMM }
}

{
    my $_format_for_yyMMM = "MMM\ yy";
    sub _format_for_yyMMM { return $_format_for_yyMMM }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyQQQQ = "QQQQ\ yy";
    sub _format_for_yyQQQQ { return $_format_for_yyQQQQ }
}

{
    my $_format_for_yyyy = "y";
    sub _format_for_yyyy { return $_format_for_yyyy }
}

{
    my $_available_formats =
        {
          "EEEd" => "d\ EEE",
          "Ed" => "d\ E",
          "H" => "H",
          "HHmm" => "HH\:mm",
          "HHmmss" => "HH\:mm\:ss",
          "Hm" => "HH\:mm",
          "M" => "L",
          "MEd" => "dd\/MM\ E",
          "MMM" => "LLL",
          "MMMEd" => "dd\ MMM\ E",
          "MMMMEd" => "dd\ MMMM\ E",
          "MMMMd" => "dd\ MMMM",
          "MMMd" => "dd\ MMM",
          "Md" => "dd\/MM",
          "d" => "d",
          "hhmm" => "hh\:mm\ a",
          "hhmmss" => "hh\:mm\:ss\ a",
          "mmss" => "mm\:ss",
          "ms" => "mm\:ss",
          "y" => "y",
          "yM" => "M\/yyyy",
          "yMEd" => "dd\.MM\.yyyy\ EEE",
          "yMMM" => "MMM\ y",
          "yMMMEd" => "dd\ MMM\ y\ EEE",
          "yMMMM" => "MMMM\ y",
          "yQ" => "Q\ yyyy",
          "yQQQ" => "QQQ\ y",
          "yyMM" => "MM\/yy",
          "yyMMM" => "MMM\ yy",
          "yyQ" => "Q\ yy",
          "yyQQQQ" => "QQQQ\ yy",
          "yyyy" => "y"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::tr

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'tr' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Turkish.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Pazartesi
  Salı
  Çarşamba
  Perşembe
  Cuma
  Cumartesi
  Pazar

=head3 Abbreviated (format)

  Pzt
  Sal
  Çar
  Per
  Cum
  Cmt
  Paz

=head3 Narrow (format)

  P
  S
  Ç
  P
  C
  C
  P

=head3 Wide (stand-alone)

  Pazartesi
  Salı
  Çarşamba
  Perşembe
  Cuma
  Cumartesi
  Pazar

=head3 Abbreviated (stand-alone)

  Pzt
  Sal
  Çar
  Per
  Cum
  Cmt
  Paz

=head3 Narrow (stand-alone)

  P
  S
  Ç
  P
  C
  C
  P

=head2 Months

=head3 Wide (format)

  Ocak
  Şubat
  Mart
  Nisan
  Mayıs
  Haziran
  Temmuz
  Ağustos
  Eylül
  Ekim
  Kasım
  Aralık

=head3 Abbreviated (format)

  Oca
  Şub
  Mar
  Nis
  May
  Haz
  Tem
  Ağu
  Eyl
  Eki
  Kas
  Ara

=head3 Narrow (format)

  O
  Ş
  M
  N
  M
  H
  T
  A
  E
  E
  K
  A

=head3 Wide (stand-alone)

  Ocak
  Şubat
  Mart
  Nisan
  Mayıs
  Haziran
  Temmuz
  Ağustos
  Eylül
  Ekim
  Kasım
  Aralık

=head3 Abbreviated (stand-alone)

  Oca
  Şub
  Mar
  Nis
  May
  Haz
  Tem
  Ağu
  Eyl
  Eki
  Kas
  Ara

=head3 Narrow (stand-alone)

  O
  Ş
  M
  N
  M
  H
  T
  A
  E
  E
  K
  A

=head2 Quarters

=head3 Wide (format)

  1. çeyrek
  2. çeyrek
  3. çeyrek
  4. çeyrek

=head3 Abbreviated (format)

  Ç1
  Ç2
  Ç3
  Ç4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  1. çeyrek
  2. çeyrek
  3. çeyrek
  4. çeyrek

=head3 Abbreviated (stand-alone)

  Ç1
  Ç2
  Ç3
  Ç4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  Milattan Önce
  Milattan Sonra

=head3 Abbreviated

  MÖ
  MS

=head3 Narrow

  MÖ
  MS

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = 05 Şubat 2008 Salı
   1995-12-22T09:05:02 = 22 Aralık 1995 Cuma
  -0010-09-15T04:44:23 = 15 Eylül -10 Cumartesi

=head3 Long

   2008-02-05T18:30:30 = 05 Şubat 2008
   1995-12-22T09:05:02 = 22 Aralık 1995
  -0010-09-15T04:44:23 = 15 Eylül -10

=head3 Medium

   2008-02-05T18:30:30 = 05 Şub 2008
   1995-12-22T09:05:02 = 22 Ara 1995
  -0010-09-15T04:44:23 = 15 Eyl -10

=head3 Short

   2008-02-05T18:30:30 = 05.02.2008
   1995-12-22T09:05:02 = 22.12.1995
  -0010-09-15T04:44:23 = 15.09.-010

=head3 Default

   2008-02-05T18:30:30 = 05 Şub 2008
   1995-12-22T09:05:02 = 22 Ara 1995
  -0010-09-15T04:44:23 = 15 Eyl -10

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = 05 Şubat 2008 Salı 18:30:30 UTC
   1995-12-22T09:05:02 = 22 Aralık 1995 Cuma 09:05:02 UTC
  -0010-09-15T04:44:23 = 15 Eylül -10 Cumartesi 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 05 Şubat 2008 18:30:30 UTC
   1995-12-22T09:05:02 = 22 Aralık 1995 09:05:02 UTC
  -0010-09-15T04:44:23 = 15 Eylül -10 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 05 Şub 2008 18:30:30
   1995-12-22T09:05:02 = 22 Ara 1995 09:05:02
  -0010-09-15T04:44:23 = 15 Eyl -10 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 05.02.2008 18:30
   1995-12-22T09:05:02 = 22.12.1995 09:05
  -0010-09-15T04:44:23 = 15.09.-010 04:44

=head3 Default

   2008-02-05T18:30:30 = 05 Şub 2008 18:30:30
   1995-12-22T09:05:02 = 22 Ara 1995 09:05:02
  -0010-09-15T04:44:23 = 15 Eyl -10 04:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 Ed (d E)

   2008-02-05T18:30:30 = 5 Sal
   1995-12-22T09:05:02 = 22 Cum
  -0010-09-15T04:44:23 = 15 Cmt

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 Sal
   1995-12-22T09:05:02 = 22 Cum
  -0010-09-15T04:44:23 = 15 Cmt

=head3 H (H)

   2008-02-05T18:30:30 = 18
   1995-12-22T09:05:02 = 9
  -0010-09-15T04:44:23 = 4

=head3 HHmm (HH:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 hhmm (hh:mm a)

   2008-02-05T18:30:30 = 06:30 PM
   1995-12-22T09:05:02 = 09:05 AM
  -0010-09-15T04:44:23 = 04:44 AM

=head3 HHmmss (HH:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 hhmmss (hh:mm:ss a)

   2008-02-05T18:30:30 = 06:30:30 PM
   1995-12-22T09:05:02 = 09:05:02 AM
  -0010-09-15T04:44:23 = 04:44:23 AM

=head3 Hm (HH:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 PM
   1995-12-22T09:05:02 = 9:05 AM
  -0010-09-15T04:44:23 = 4:44 AM

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 PM
   1995-12-22T09:05:02 = 9:05:02 AM
  -0010-09-15T04:44:23 = 4:44:23 AM

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (dd/MM)

   2008-02-05T18:30:30 = 05/02
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/09

=head3 MEd (dd/MM E)

   2008-02-05T18:30:30 = 05/02 Sal
   1995-12-22T09:05:02 = 22/12 Cum
  -0010-09-15T04:44:23 = 15/09 Cmt

=head3 MMM (LLL)

   2008-02-05T18:30:30 = Şub
   1995-12-22T09:05:02 = Ara
  -0010-09-15T04:44:23 = Eyl

=head3 MMMd (dd MMM)

   2008-02-05T18:30:30 = 05 Şub
   1995-12-22T09:05:02 = 22 Ara
  -0010-09-15T04:44:23 = 15 Eyl

=head3 MMMEd (dd MMM E)

   2008-02-05T18:30:30 = 05 Şub Sal
   1995-12-22T09:05:02 = 22 Ara Cum
  -0010-09-15T04:44:23 = 15 Eyl Cmt

=head3 MMMMd (dd MMMM)

   2008-02-05T18:30:30 = 05 Şubat
   1995-12-22T09:05:02 = 22 Aralık
  -0010-09-15T04:44:23 = 15 Eylül

=head3 MMMMEd (dd MMMM E)

   2008-02-05T18:30:30 = 05 Şubat Sal
   1995-12-22T09:05:02 = 22 Aralık Cum
  -0010-09-15T04:44:23 = 15 Eylül Cmt

=head3 mmss (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (M/yyyy)

   2008-02-05T18:30:30 = 2/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 9/-010

=head3 yMEd (dd.MM.yyyy EEE)

   2008-02-05T18:30:30 = 05.02.2008 Sal
   1995-12-22T09:05:02 = 22.12.1995 Cum
  -0010-09-15T04:44:23 = 15.09.-010 Cmt

=head3 yMMM (MMM y)

   2008-02-05T18:30:30 = Şub 2008
   1995-12-22T09:05:02 = Ara 1995
  -0010-09-15T04:44:23 = Eyl -10

=head3 yMMMEd (dd MMM y EEE)

   2008-02-05T18:30:30 = 05 Şub 2008 Sal
   1995-12-22T09:05:02 = 22 Ara 1995 Cum
  -0010-09-15T04:44:23 = 15 Eyl -10 Cmt

=head3 yMMMM (MMMM y)

   2008-02-05T18:30:30 = Şubat 2008
   1995-12-22T09:05:02 = Aralık 1995
  -0010-09-15T04:44:23 = Eylül -10

=head3 yQ (Q yyyy)

   2008-02-05T18:30:30 = 1 2008
   1995-12-22T09:05:02 = 4 1995
  -0010-09-15T04:44:23 = 3 -010

=head3 yQQQ (QQQ y)

   2008-02-05T18:30:30 = Ç1 2008
   1995-12-22T09:05:02 = Ç4 1995
  -0010-09-15T04:44:23 = Ç3 -10

=head3 yyMM (MM/yy)

   2008-02-05T18:30:30 = 02/08
   1995-12-22T09:05:02 = 12/95
  -0010-09-15T04:44:23 = 09/-10

=head3 yyMMM (MMM yy)

   2008-02-05T18:30:30 = Şub 08
   1995-12-22T09:05:02 = Ara 95
  -0010-09-15T04:44:23 = Eyl -10

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyQQQQ (QQQQ yy)

   2008-02-05T18:30:30 = 1. çeyrek 08
   1995-12-22T09:05:02 = 4. çeyrek 95
  -0010-09-15T04:44:23 = 3. çeyrek -10

=head3 yyyy (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

Pazartesi


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
