###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file ru.xml
# The source file version number was 1.144, generated on
# 2009/06/15 03:46:23.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ru;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "AM", "PM" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\,\ d\ MMMM\ y\ \'г\'\.";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\ MMMM\ y\ \'г\'\.";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "dd\.MM\.yyyy";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "dd\.MM\.yy";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "Пн", "Вт", "Ср", "Чт", "Пт", "Сб", "Вс" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "понедельник", "вторник", "среда", "четверг", "пятница", "суббота", "воскресенье" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "П", "В", "С", "Ч", "П", "С", "В" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}
{
    my $day_stand_alone_wide = [ "Понедельник", "Вторник", "Среда", "Четверг", "Пятница", "Суббота", "Воскресенье" ];
    sub day_stand_alone_wide { return $day_stand_alone_wide }
}
{
    my $era_abbreviated = [ "до\ н\.э\.", "н\.э\." ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "до\ н\.э\.", "н\.э\." ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "янв\.", "февр\.", "марта", "апр\.", "мая", "июня", "июля", "авг\.", "сент\.", "окт\.", "нояб\.", "дек\." ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "января", "февраля", "марта", "апреля", "мая", "июня", "июля", "августа", "сентября", "октября", "ноября", "декабря" ];
    sub month_format_wide { return $month_format_wide }
}
{
    my $month_stand_alone_abbreviated = [ "янв\.", "февр\.", "март", "апр\.", "май", "июнь", "июль", "авг\.", "сент\.", "окт\.", "нояб\.", "дек\." ];
    sub month_stand_alone_abbreviated { return $month_stand_alone_abbreviated }
}
{
    my $month_stand_alone_narrow = [ "Я", "Ф", "М", "А", "М", "И", "И", "А", "С", "О", "Н", "Д" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}
{
    my $month_stand_alone_wide = [ "Январь", "Февраль", "Март", "Апрель", "Май", "Июнь", "Июль", "Август", "Сентябрь", "Октябрь", "Ноябрь", "Декабрь" ];
    sub month_stand_alone_wide { return $month_stand_alone_wide }
}
{
    my $quarter_format_abbreviated = [ "1\-й\ кв\.", "2\-й\ кв\.", "3\-й\ кв\.", "4\-й\ кв\." ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "1\-й\ квартал", "2\-й\ квартал", "3\-й\ квартал", "4\-й\ квартал" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "H\:mm\:ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "H\:mm\:ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "H\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "H\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_Ed = "E\ d";
    sub _format_for_Ed { return $_format_for_Ed }
}

{
    my $_format_for_H = "H";
    sub _format_for_H { return $_format_for_H }
}

{
    my $_format_for_HHmm = "HH\:mm";
    sub _format_for_HHmm { return $_format_for_HHmm }
}

{
    my $_format_for_HHmmss = "HH\:mm\:ss";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_Hm = "H\:mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "E\,\ M\-d";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "E\ MMM\ d";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "E\ MMMM\ d";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "d\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "d\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_MMdd = "dd\.MM";
    sub _format_for_MMdd { return $_format_for_MMdd }
}

{
    my $_format_for_Md = "d\.M";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_mmss = "mm\:ss";
    sub _format_for_mmss { return $_format_for_mmss }
}

{
    my $_format_for_ms = "mm\:ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "yyyy\-M";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "EEE\,\ yyyy\-M\-d";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "MMM\ y";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "E\,\ d\ MMM\ y";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "MMMM\ y";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yQ = "Q\ y";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "y\ QQQ";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyMM = "MM\.yy";
    sub _format_for_yyMM { return $_format_for_yyMM }
}

{
    my $_format_for_yyMMM = "MMM\ yy";
    sub _format_for_yyMMM { return $_format_for_yyMMM }
}

{
    my $_format_for_yyMMMEEEd = "EEE\,\ d\ MMM\ yy";
    sub _format_for_yyMMMEEEd { return $_format_for_yyMMMEEEd }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyy = "y";
    sub _format_for_yyyy { return $_format_for_yyyy }
}

{
    my $_format_for_yyyyLLLL = "LLLL\ y";
    sub _format_for_yyyyLLLL { return $_format_for_yyyyLLLL }
}

{
    my $_format_for_yyyyMM = "MM\.yyyy";
    sub _format_for_yyyyMM { return $_format_for_yyyyMM }
}

{
    my $_format_for_yyyyMMMM = "MMMM\ y";
    sub _format_for_yyyyMMMM { return $_format_for_yyyyMMMM }
}

{
    my $_format_for_yyyyQQQQ = "QQQQ\ y\ \'г\'\.";
    sub _format_for_yyyyQQQQ { return $_format_for_yyyyQQQQ }
}

{
    my $_available_formats =
        {
          "Ed" => "E\ d",
          "H" => "H",
          "HHmm" => "HH\:mm",
          "HHmmss" => "HH\:mm\:ss",
          "Hm" => "H\:mm",
          "M" => "L",
          "MEd" => "E\,\ M\-d",
          "MMM" => "LLL",
          "MMMEd" => "E\ MMM\ d",
          "MMMMEd" => "E\ MMMM\ d",
          "MMMMd" => "d\ MMMM",
          "MMMd" => "d\ MMM",
          "MMdd" => "dd\.MM",
          "Md" => "d\.M",
          "d" => "d",
          "mmss" => "mm\:ss",
          "ms" => "mm\:ss",
          "y" => "y",
          "yM" => "yyyy\-M",
          "yMEd" => "EEE\,\ yyyy\-M\-d",
          "yMMM" => "MMM\ y",
          "yMMMEd" => "E\,\ d\ MMM\ y",
          "yMMMM" => "MMMM\ y",
          "yQ" => "Q\ y",
          "yQQQ" => "y\ QQQ",
          "yyMM" => "MM\.yy",
          "yyMMM" => "MMM\ yy",
          "yyMMMEEEd" => "EEE\,\ d\ MMM\ yy",
          "yyQ" => "Q\ yy",
          "yyyy" => "y",
          "yyyyLLLL" => "LLLL\ y",
          "yyyyMM" => "MM\.yyyy",
          "yyyyMMMM" => "MMMM\ y",
          "yyyyQQQQ" => "QQQQ\ y\ \'г\'\."
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::ru

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'ru' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Russian.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  понедельник
  вторник
  среда
  четверг
  пятница
  суббота
  воскресенье

=head3 Abbreviated (format)

  Пн
  Вт
  Ср
  Чт
  Пт
  Сб
  Вс

=head3 Narrow (format)

  П
  В
  С
  Ч
  П
  С
  В

=head3 Wide (stand-alone)

  Понедельник
  Вторник
  Среда
  Четверг
  Пятница
  Суббота
  Воскресенье

=head3 Abbreviated (stand-alone)

  Пн
  Вт
  Ср
  Чт
  Пт
  Сб
  Вс

=head3 Narrow (stand-alone)

  П
  В
  С
  Ч
  П
  С
  В

=head2 Months

=head3 Wide (format)

  января
  февраля
  марта
  апреля
  мая
  июня
  июля
  августа
  сентября
  октября
  ноября
  декабря

=head3 Abbreviated (format)

  янв.
  февр.
  марта
  апр.
  мая
  июня
  июля
  авг.
  сент.
  окт.
  нояб.
  дек.

=head3 Narrow (format)

  Я
  Ф
  М
  А
  М
  И
  И
  А
  С
  О
  Н
  Д

=head3 Wide (stand-alone)

  Январь
  Февраль
  Март
  Апрель
  Май
  Июнь
  Июль
  Август
  Сентябрь
  Октябрь
  Ноябрь
  Декабрь

=head3 Abbreviated (stand-alone)

  янв.
  февр.
  март
  апр.
  май
  июнь
  июль
  авг.
  сент.
  окт.
  нояб.
  дек.

=head3 Narrow (stand-alone)

  Я
  Ф
  М
  А
  М
  И
  И
  А
  С
  О
  Н
  Д

=head2 Quarters

=head3 Wide (format)

  1-й квартал
  2-й квартал
  3-й квартал
  4-й квартал

=head3 Abbreviated (format)

  1-й кв.
  2-й кв.
  3-й кв.
  4-й кв.

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  1-й квартал
  2-й квартал
  3-й квартал
  4-й квартал

=head3 Abbreviated (stand-alone)

  1-й кв.
  2-й кв.
  3-й кв.
  4-й кв.

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  до н.э.
  н.э.

=head3 Abbreviated

  до н.э.
  н.э.

=head3 Narrow

  до н.э.
  н.э.

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = вторник, 5 февраля 2008 г.
   1995-12-22T09:05:02 = пятница, 22 декабря 1995 г.
  -0010-09-15T04:44:23 = суббота, 15 сентября -10 г.

=head3 Long

   2008-02-05T18:30:30 = 5 февраля 2008 г.
   1995-12-22T09:05:02 = 22 декабря 1995 г.
  -0010-09-15T04:44:23 = 15 сентября -10 г.

=head3 Medium

   2008-02-05T18:30:30 = 05.02.2008
   1995-12-22T09:05:02 = 22.12.1995
  -0010-09-15T04:44:23 = 15.09.-010

=head3 Short

   2008-02-05T18:30:30 = 05.02.08
   1995-12-22T09:05:02 = 22.12.95
  -0010-09-15T04:44:23 = 15.09.-10

=head3 Default

   2008-02-05T18:30:30 = 05.02.2008
   1995-12-22T09:05:02 = 22.12.1995
  -0010-09-15T04:44:23 = 15.09.-010

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 9:05:02 UTC
  -0010-09-15T04:44:23 = 4:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 9:05:02 UTC
  -0010-09-15T04:44:23 = 4:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = вторник, 5 февраля 2008 г. 18:30:30 UTC
   1995-12-22T09:05:02 = пятница, 22 декабря 1995 г. 9:05:02 UTC
  -0010-09-15T04:44:23 = суббота, 15 сентября -10 г. 4:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 5 февраля 2008 г. 18:30:30 UTC
   1995-12-22T09:05:02 = 22 декабря 1995 г. 9:05:02 UTC
  -0010-09-15T04:44:23 = 15 сентября -10 г. 4:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 05.02.2008 18:30:30
   1995-12-22T09:05:02 = 22.12.1995 9:05:02
  -0010-09-15T04:44:23 = 15.09.-010 4:44:23

=head3 Short

   2008-02-05T18:30:30 = 05.02.08 18:30
   1995-12-22T09:05:02 = 22.12.95 9:05
  -0010-09-15T04:44:23 = 15.09.-10 4:44

=head3 Default

   2008-02-05T18:30:30 = 05.02.2008 18:30:30
   1995-12-22T09:05:02 = 22.12.1995 9:05:02
  -0010-09-15T04:44:23 = 15.09.-010 4:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 Ed (E d)

   2008-02-05T18:30:30 = Вт 5
   1995-12-22T09:05:02 = Пт 22
  -0010-09-15T04:44:23 = Сб 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 Вт
   1995-12-22T09:05:02 = 22 Пт
  -0010-09-15T04:44:23 = 15 Сб

=head3 H (H)

   2008-02-05T18:30:30 = 18
   1995-12-22T09:05:02 = 9
  -0010-09-15T04:44:23 = 4

=head3 HHmm (HH:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 HHmmss (HH:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 PM
   1995-12-22T09:05:02 = 9:05 AM
  -0010-09-15T04:44:23 = 4:44 AM

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 PM
   1995-12-22T09:05:02 = 9:05:02 AM
  -0010-09-15T04:44:23 = 4:44:23 AM

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (d.M)

   2008-02-05T18:30:30 = 5.2
   1995-12-22T09:05:02 = 22.12
  -0010-09-15T04:44:23 = 15.9

=head3 MEd (E, M-d)

   2008-02-05T18:30:30 = Вт, 2-5
   1995-12-22T09:05:02 = Пт, 12-22
  -0010-09-15T04:44:23 = Сб, 9-15

=head3 MMdd (dd.MM)

   2008-02-05T18:30:30 = 05.02
   1995-12-22T09:05:02 = 22.12
  -0010-09-15T04:44:23 = 15.09

=head3 MMM (LLL)

   2008-02-05T18:30:30 = февр.
   1995-12-22T09:05:02 = дек.
  -0010-09-15T04:44:23 = сент.

=head3 MMMd (d MMM)

   2008-02-05T18:30:30 = 5 февр.
   1995-12-22T09:05:02 = 22 дек.
  -0010-09-15T04:44:23 = 15 сент.

=head3 MMMEd (E MMM d)

   2008-02-05T18:30:30 = Вт февр. 5
   1995-12-22T09:05:02 = Пт дек. 22
  -0010-09-15T04:44:23 = Сб сент. 15

=head3 MMMMd (d MMMM)

   2008-02-05T18:30:30 = 5 февраля
   1995-12-22T09:05:02 = 22 декабря
  -0010-09-15T04:44:23 = 15 сентября

=head3 MMMMEd (E MMMM d)

   2008-02-05T18:30:30 = Вт февраля 5
   1995-12-22T09:05:02 = Пт декабря 22
  -0010-09-15T04:44:23 = Сб сентября 15

=head3 mmss (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (yyyy-M)

   2008-02-05T18:30:30 = 2008-2
   1995-12-22T09:05:02 = 1995-12
  -0010-09-15T04:44:23 = -010-9

=head3 yMEd (EEE, yyyy-M-d)

   2008-02-05T18:30:30 = Вт, 2008-2-5
   1995-12-22T09:05:02 = Пт, 1995-12-22
  -0010-09-15T04:44:23 = Сб, -010-9-15

=head3 yMMM (MMM y)

   2008-02-05T18:30:30 = февр. 2008
   1995-12-22T09:05:02 = дек. 1995
  -0010-09-15T04:44:23 = сент. -10

=head3 yMMMEd (E, d MMM y)

   2008-02-05T18:30:30 = Вт, 5 февр. 2008
   1995-12-22T09:05:02 = Пт, 22 дек. 1995
  -0010-09-15T04:44:23 = Сб, 15 сент. -10

=head3 yMMMM (MMMM y)

   2008-02-05T18:30:30 = февраля 2008
   1995-12-22T09:05:02 = декабря 1995
  -0010-09-15T04:44:23 = сентября -10

=head3 yQ (Q y)

   2008-02-05T18:30:30 = 1 2008
   1995-12-22T09:05:02 = 4 1995
  -0010-09-15T04:44:23 = 3 -10

=head3 yQQQ (y QQQ)

   2008-02-05T18:30:30 = 2008 1-й кв.
   1995-12-22T09:05:02 = 1995 4-й кв.
  -0010-09-15T04:44:23 = -10 3-й кв.

=head3 yyMM (MM.yy)

   2008-02-05T18:30:30 = 02.08
   1995-12-22T09:05:02 = 12.95
  -0010-09-15T04:44:23 = 09.-10

=head3 yyMMM (MMM yy)

   2008-02-05T18:30:30 = февр. 08
   1995-12-22T09:05:02 = дек. 95
  -0010-09-15T04:44:23 = сент. -10

=head3 yyMMMEEEd (EEE, d MMM yy)

   2008-02-05T18:30:30 = Вт, 5 февр. 08
   1995-12-22T09:05:02 = Пт, 22 дек. 95
  -0010-09-15T04:44:23 = Сб, 15 сент. -10

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyyy (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yyyyLLLL (LLLL y)

   2008-02-05T18:30:30 = Февраль 2008
   1995-12-22T09:05:02 = Декабрь 1995
  -0010-09-15T04:44:23 = Сентябрь -10

=head3 yyyyMM (MM.yyyy)

   2008-02-05T18:30:30 = 02.2008
   1995-12-22T09:05:02 = 12.1995
  -0010-09-15T04:44:23 = 09.-010

=head3 yyyyMMMM (MMMM y)

   2008-02-05T18:30:30 = февраля 2008
   1995-12-22T09:05:02 = декабря 1995
  -0010-09-15T04:44:23 = сентября -10

=head3 yyyyQQQQ (QQQQ y 'г'.)

   2008-02-05T18:30:30 = 1-й квартал 2008 г.
   1995-12-22T09:05:02 = 4-й квартал 1995 г.
  -0010-09-15T04:44:23 = 3-й квартал -10 г.

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

понедельник


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
