###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file eo.xml
# The source file version number was 1.76, generated on
# 2009/06/15 03:46:25.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::eo;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "atm", "ptm" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\,\ d\-\'a\'\ \'de\'\ MMMM\ y";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "y\-MMMM\-dd";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "y\-MMM\-dd";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "yy\-MM\-dd";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "lu", "ma", "me", "ĵa", "ve", "sa", "di" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "lundo", "mardo", "merkredo", "ĵaŭdo", "vendredo", "sabato", "dimanĉo" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "2", "3", "4", "5", "6", "7", "1" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "aK", "pK" ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "jan", "feb", "mar", "apr", "maj", "jun", "jul", "aŭg", "sep", "okt", "nov", "dec" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "januaro", "februaro", "marto", "aprilo", "majo", "junio", "julio", "aŭgusto", "septembro", "oktobro", "novembro", "decembro" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "K1", "K2", "K3", "K4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}
{
    my $quarter_format_wide = [ "1a\ kvaronjaro", "2a\ kvaronjaro", "3a\ kvaronjaro", "4a\ kvaronjaro" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }


sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "H\-\'a\'\ \'horo\'\ \'kaj\'\ m\:ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\:mm\:ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_available_formats =
        {
          "yyQ" => "Q\ yy"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::eo

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'eo' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Esperanto.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  lundo
  mardo
  merkredo
  ĵaŭdo
  vendredo
  sabato
  dimanĉo

=head3 Abbreviated (format)

  lu
  ma
  me
  ĵa
  ve
  sa
  di

=head3 Narrow (format)

  2
  3
  4
  5
  6
  7
  1

=head3 Wide (stand-alone)

  lundo
  mardo
  merkredo
  ĵaŭdo
  vendredo
  sabato
  dimanĉo

=head3 Abbreviated (stand-alone)

  lu
  ma
  me
  ĵa
  ve
  sa
  di

=head3 Narrow (stand-alone)

  2
  3
  4
  5
  6
  7
  1

=head2 Months

=head3 Wide (format)

  januaro
  februaro
  marto
  aprilo
  majo
  junio
  julio
  aŭgusto
  septembro
  oktobro
  novembro
  decembro

=head3 Abbreviated (format)

  jan
  feb
  mar
  apr
  maj
  jun
  jul
  aŭg
  sep
  okt
  nov
  dec

=head3 Narrow (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Wide (stand-alone)

  januaro
  februaro
  marto
  aprilo
  majo
  junio
  julio
  aŭgusto
  septembro
  oktobro
  novembro
  decembro

=head3 Abbreviated (stand-alone)

  jan
  feb
  mar
  apr
  maj
  jun
  jul
  aŭg
  sep
  okt
  nov
  dec

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  1a kvaronjaro
  2a kvaronjaro
  3a kvaronjaro
  4a kvaronjaro

=head3 Abbreviated (format)

  K1
  K2
  K3
  K4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  1a kvaronjaro
  2a kvaronjaro
  3a kvaronjaro
  4a kvaronjaro

=head3 Abbreviated (stand-alone)

  K1
  K2
  K3
  K4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  BCE
  CE

=head3 Abbreviated

  aK
  pK

=head3 Narrow

  aK
  pK

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = mardo, 5-a de februaro 2008
   1995-12-22T09:05:02 = vendredo, 22-a de decembro 1995
  -0010-09-15T04:44:23 = sabato, 15-a de septembro -10

=head3 Long

   2008-02-05T18:30:30 = 2008-februaro-05
   1995-12-22T09:05:02 = 1995-decembro-22
  -0010-09-15T04:44:23 = -10-septembro-15

=head3 Medium

   2008-02-05T18:30:30 = 2008-feb-05
   1995-12-22T09:05:02 = 1995-dec-22
  -0010-09-15T04:44:23 = -10-sep-15

=head3 Short

   2008-02-05T18:30:30 = 08-02-05
   1995-12-22T09:05:02 = 95-12-22
  -0010-09-15T04:44:23 = -10-09-15

=head3 Default

   2008-02-05T18:30:30 = 2008-feb-05
   1995-12-22T09:05:02 = 1995-dec-22
  -0010-09-15T04:44:23 = -10-sep-15

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18-a horo kaj 30:30 UTC
   1995-12-22T09:05:02 = 9-a horo kaj 5:02 UTC
  -0010-09-15T04:44:23 = 4-a horo kaj 44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = mardo, 5-a de februaro 2008 18-a horo kaj 30:30 UTC
   1995-12-22T09:05:02 = vendredo, 22-a de decembro 1995 9-a horo kaj 5:02 UTC
  -0010-09-15T04:44:23 = sabato, 15-a de septembro -10 4-a horo kaj 44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 2008-februaro-05 18:30:30 UTC
   1995-12-22T09:05:02 = 1995-decembro-22 09:05:02 UTC
  -0010-09-15T04:44:23 = -10-septembro-15 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 2008-feb-05 18:30:30
   1995-12-22T09:05:02 = 1995-dec-22 09:05:02
  -0010-09-15T04:44:23 = -10-sep-15 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 08-02-05 18:30
   1995-12-22T09:05:02 = 95-12-22 09:05
  -0010-09-15T04:44:23 = -10-09-15 04:44

=head3 Default

   2008-02-05T18:30:30 = 2008-feb-05 18:30:30
   1995-12-22T09:05:02 = 1995-dec-22 09:05:02
  -0010-09-15T04:44:23 = -10-sep-15 04:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 ma
   1995-12-22T09:05:02 = 22 ve
  -0010-09-15T04:44:23 = 15 sa

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 ptm
   1995-12-22T09:05:02 = 9:05 atm
  -0010-09-15T04:44:23 = 4:44 atm

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 ptm
   1995-12-22T09:05:02 = 9:05:02 atm
  -0010-09-15T04:44:23 = 4:44:23 atm

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (M-d)

   2008-02-05T18:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-09-15T04:44:23 = 9-15

=head3 MEd (E, M-d)

   2008-02-05T18:30:30 = ma, 2-5
   1995-12-22T09:05:02 = ve, 12-22
  -0010-09-15T04:44:23 = sa, 9-15

=head3 MMM (LLL)

   2008-02-05T18:30:30 = feb
   1995-12-22T09:05:02 = dec
  -0010-09-15T04:44:23 = sep

=head3 MMMd (MMM d)

   2008-02-05T18:30:30 = feb 5
   1995-12-22T09:05:02 = dec 22
  -0010-09-15T04:44:23 = sep 15

=head3 MMMEd (E MMM d)

   2008-02-05T18:30:30 = ma feb 5
   1995-12-22T09:05:02 = ve dec 22
  -0010-09-15T04:44:23 = sa sep 15

=head3 MMMMd (MMMM d)

   2008-02-05T18:30:30 = februaro 5
   1995-12-22T09:05:02 = decembro 22
  -0010-09-15T04:44:23 = septembro 15

=head3 MMMMEd (E MMMM d)

   2008-02-05T18:30:30 = ma februaro 5
   1995-12-22T09:05:02 = ve decembro 22
  -0010-09-15T04:44:23 = sa septembro 15

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (y-M)

   2008-02-05T18:30:30 = 2008-2
   1995-12-22T09:05:02 = 1995-12
  -0010-09-15T04:44:23 = -10-9

=head3 yMEd (EEE, y-M-d)

   2008-02-05T18:30:30 = ma, 2008-2-5
   1995-12-22T09:05:02 = ve, 1995-12-22
  -0010-09-15T04:44:23 = sa, -10-9-15

=head3 yMMM (y MMM)

   2008-02-05T18:30:30 = 2008 feb
   1995-12-22T09:05:02 = 1995 dec
  -0010-09-15T04:44:23 = -10 sep

=head3 yMMMEd (EEE, y MMM d)

   2008-02-05T18:30:30 = ma, 2008 feb 5
   1995-12-22T09:05:02 = ve, 1995 dec 22
  -0010-09-15T04:44:23 = sa, -10 sep 15

=head3 yMMMM (y MMMM)

   2008-02-05T18:30:30 = 2008 februaro
   1995-12-22T09:05:02 = 1995 decembro
  -0010-09-15T04:44:23 = -10 septembro

=head3 yQ (y Q)

   2008-02-05T18:30:30 = 2008 1
   1995-12-22T09:05:02 = 1995 4
  -0010-09-15T04:44:23 = -10 3

=head3 yQQQ (y QQQ)

   2008-02-05T18:30:30 = 2008 K1
   1995-12-22T09:05:02 = 1995 K4
  -0010-09-15T04:44:23 = -10 K3

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

lundo


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
