###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file my.xml
# The source file version number was 1.41, generated on
# 2009/06/15 04:15:33.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::my;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "နံနက်", "ညနေ" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\,\ y\ MMMM\ dd";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "y\ MMMM\ d";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "y\ MMM\ d";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "yy\/MM\/dd";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "လာ", "ဂါ", "ဟူး", "တေး", "ကြာ", "နေ", "နွေ" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "တနင်္လာ", "အင်္ဂါ", "ဗုဒ္ဓဟူး", "ကြာသပတေး", "သောကြာ", "စနေ", "တနင်္ဂနွေ" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "တ", "အ", "ဗ", "က", "သ", "စ", "တ" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "ဘီစီ", "အေဒီ" ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "ခရစ်တော်\ မပေါ်မီကာလ", "ခရစ်တော်\ ပေါ်ထွန်းပြီးကာလ" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "ဇန်", "ဖေ", "မတ်", "ဧ", "မေ", "ဇွန်", "ဇူ", "ဩ", "စက်", "အောက်", "နို", "ဒီ" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "ဇန်နဝါရီ", "ဖေဖော်ဝါရီ", "မတ်", "ဧပြီ", "မေ", "ဇွန်", "ဇူလိုင်", "ဩဂုတ်", "စက်တင်ဘာ", "အောက်တိုဘာ", "နိုဝင်ဘာ", "ဒီဇင်ဘာ" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "ဇ", "ဖ", "မ", "ဧ", "မ", "ဇ", "ဇ", "ဩ", "စ", "အ", "န", "ဒ" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "ပ\-စိတ်", "ဒု\-စိတ်", "တ\-စိတ်", "စ\-စိတ်" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "ပထမ\ သုံးလပတ်", "ဒုတိယ\ သုံးလပတ်", "တတိယ\ သုံးလပတ်", "စတုတ္ထ\ သုံးလပတ်" ];
    sub quarter_format_wide { return $quarter_format_wide }
}
{
    my $quarter_stand_alone_abbreviated = [ "ပ\-စိတ်", "ဒု\-စိတ်", "တ\-စိတ်", "စ\-စိတ်" ];
    sub quarter_stand_alone_abbreviated { return $quarter_stand_alone_abbreviated }
}
{
    my $quarter_stand_alone_narrow = [ "ပ", "ဒု", "တ", "စ" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}
{
    my $quarter_stand_alone_wide = [ "ပထမ\ သုံးလပတ်", "ဒုတိယ\ သုံးလပတ်", "တတိယ\ သုံးလပတ်", "စတုတ္ထ\ သုံးလပတ်" ];
    sub quarter_stand_alone_wide { return $quarter_stand_alone_wide }
}
{
    my $time_format_full = "HH\:mm\:ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\:mm\:ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_Hm = "H\:mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "E\,\ M\-d";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "E\ MMM\ d";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "E\ MMMM\ d";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "MMMM\ d";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "MMM\ d";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_Md = "M\-d";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_ms = "mm\:ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "yyyy\-M";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "EEE\,\ yyyy\-M\-d";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "y\ MMM";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "EEE\,\ y\ MMM\ d";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "y\ MMMM";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yQ = "yyyy\ Q";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "y\ QQQ";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_available_formats =
        {
          "Hm" => "H\:mm",
          "M" => "L",
          "MEd" => "E\,\ M\-d",
          "MMM" => "LLL",
          "MMMEd" => "E\ MMM\ d",
          "MMMMEd" => "E\ MMMM\ d",
          "MMMMd" => "MMMM\ d",
          "MMMd" => "MMM\ d",
          "Md" => "M\-d",
          "d" => "d",
          "ms" => "mm\:ss",
          "y" => "y",
          "yM" => "yyyy\-M",
          "yMEd" => "EEE\,\ yyyy\-M\-d",
          "yMMM" => "y\ MMM",
          "yMMMEd" => "EEE\,\ y\ MMM\ d",
          "yMMMM" => "y\ MMMM",
          "yQ" => "yyyy\ Q",
          "yQQQ" => "y\ QQQ",
          "yyQ" => "Q\ yy"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::my

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'my' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Burmese.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  တနင်္လာ
  အင်္ဂါ
  ဗုဒ္ဓဟူး
  ကြာသပတေး
  သောကြာ
  စနေ
  တနင်္ဂနွေ

=head3 Abbreviated (format)

  လာ
  ဂါ
  ဟူး
  တေး
  ကြာ
  နေ
  နွေ

=head3 Narrow (format)

  တ
  အ
  ဗ
  က
  သ
  စ
  တ

=head3 Wide (stand-alone)

  တနင်္လာ
  အင်္ဂါ
  ဗုဒ္ဓဟူး
  ကြာသပတေး
  သောကြာ
  စနေ
  တနင်္ဂနွေ

=head3 Abbreviated (stand-alone)

  လာ
  ဂါ
  ဟူး
  တေး
  ကြာ
  နေ
  နွေ

=head3 Narrow (stand-alone)

  တ
  အ
  ဗ
  က
  သ
  စ
  တ

=head2 Months

=head3 Wide (format)

  ဇန်နဝါရီ
  ဖေဖော်ဝါရီ
  မတ်
  ဧပြီ
  မေ
  ဇွန်
  ဇူလိုင်
  ဩဂုတ်
  စက်တင်ဘာ
  အောက်တိုဘာ
  နိုဝင်ဘာ
  ဒီဇင်ဘာ

=head3 Abbreviated (format)

  ဇန်
  ဖေ
  မတ်
  ဧ
  မေ
  ဇွန်
  ဇူ
  ဩ
  စက်
  အောက်
  နို
  ဒီ

=head3 Narrow (format)

  ဇ
  ဖ
  မ
  ဧ
  မ
  ဇ
  ဇ
  ဩ
  စ
  အ
  န
  ဒ

=head3 Wide (stand-alone)

  ဇန်နဝါရီ
  ဖေဖော်ဝါရီ
  မတ်
  ဧပြီ
  မေ
  ဇွန်
  ဇူလိုင်
  ဩဂုတ်
  စက်တင်ဘာ
  အောက်တိုဘာ
  နိုဝင်ဘာ
  ဒီဇင်ဘာ

=head3 Abbreviated (stand-alone)

  ဇန်
  ဖေ
  မတ်
  ဧ
  မေ
  ဇွန်
  ဇူ
  ဩ
  စက်
  အောက်
  နို
  ဒီ

=head3 Narrow (stand-alone)

  ဇ
  ဖ
  မ
  ဧ
  မ
  ဇ
  ဇ
  ဩ
  စ
  အ
  န
  ဒ

=head2 Quarters

=head3 Wide (format)

  ပထမ သုံးလပတ်
  ဒုတိယ သုံးလပတ်
  တတိယ သုံးလပတ်
  စတုတ္ထ သုံးလပတ်

=head3 Abbreviated (format)

  ပ-စိတ်
  ဒု-စိတ်
  တ-စိတ်
  စ-စိတ်

=head3 Narrow (format)

  ပ
  ဒု
  တ
  စ

=head3 Wide (stand-alone)

  ပထမ သုံးလပတ်
  ဒုတိယ သုံးလပတ်
  တတိယ သုံးလပတ်
  စတုတ္ထ သုံးလပတ်

=head3 Abbreviated (stand-alone)

  ပ-စိတ်
  ဒု-စိတ်
  တ-စိတ်
  စ-စိတ်

=head3 Narrow (stand-alone)

  ပ
  ဒု
  တ
  စ

=head2 Eras

=head3 Wide

  ခရစ်တော် မပေါ်မီကာလ
  ခရစ်တော် ပေါ်ထွန်းပြီးကာလ

=head3 Abbreviated

  ဘီစီ
  အေဒီ

=head3 Narrow

  ဘီစီ
  အေဒီ

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = အင်္ဂါ, 2008 ဖေဖော်ဝါရီ 05
   1995-12-22T09:05:02 = သောကြာ, 1995 ဒီဇင်ဘာ 22
  -0010-09-15T04:44:23 = စနေ, -10 စက်တင်ဘာ 15

=head3 Long

   2008-02-05T18:30:30 = 2008 ဖေဖော်ဝါရီ 5
   1995-12-22T09:05:02 = 1995 ဒီဇင်ဘာ 22
  -0010-09-15T04:44:23 = -10 စက်တင်ဘာ 15

=head3 Medium

   2008-02-05T18:30:30 = 2008 ဖေ 5
   1995-12-22T09:05:02 = 1995 ဒီ 22
  -0010-09-15T04:44:23 = -10 စက် 15

=head3 Short

   2008-02-05T18:30:30 = 08/02/05
   1995-12-22T09:05:02 = 95/12/22
  -0010-09-15T04:44:23 = -10/09/15

=head3 Default

   2008-02-05T18:30:30 = 2008 ဖေ 5
   1995-12-22T09:05:02 = 1995 ဒီ 22
  -0010-09-15T04:44:23 = -10 စက် 15

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = အင်္ဂါ, 2008 ဖေဖော်ဝါရီ 05 18:30:30 UTC
   1995-12-22T09:05:02 = သောကြာ, 1995 ဒီဇင်ဘာ 22 09:05:02 UTC
  -0010-09-15T04:44:23 = စနေ, -10 စက်တင်ဘာ 15 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 2008 ဖေဖော်ဝါရီ 5 18:30:30 UTC
   1995-12-22T09:05:02 = 1995 ဒီဇင်ဘာ 22 09:05:02 UTC
  -0010-09-15T04:44:23 = -10 စက်တင်ဘာ 15 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 2008 ဖေ 5 18:30:30
   1995-12-22T09:05:02 = 1995 ဒီ 22 09:05:02
  -0010-09-15T04:44:23 = -10 စက် 15 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 08/02/05 18:30
   1995-12-22T09:05:02 = 95/12/22 09:05
  -0010-09-15T04:44:23 = -10/09/15 04:44

=head3 Default

   2008-02-05T18:30:30 = 2008 ဖေ 5 18:30:30
   1995-12-22T09:05:02 = 1995 ဒီ 22 09:05:02
  -0010-09-15T04:44:23 = -10 စက် 15 04:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 ဂါ
   1995-12-22T09:05:02 = 22 ကြာ
  -0010-09-15T04:44:23 = 15 နေ

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 ညနေ
   1995-12-22T09:05:02 = 9:05 နံနက်
  -0010-09-15T04:44:23 = 4:44 နံနက်

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 ညနေ
   1995-12-22T09:05:02 = 9:05:02 နံနက်
  -0010-09-15T04:44:23 = 4:44:23 နံနက်

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (M-d)

   2008-02-05T18:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-09-15T04:44:23 = 9-15

=head3 MEd (E, M-d)

   2008-02-05T18:30:30 = ဂါ, 2-5
   1995-12-22T09:05:02 = ကြာ, 12-22
  -0010-09-15T04:44:23 = နေ, 9-15

=head3 MMM (LLL)

   2008-02-05T18:30:30 = ဖေ
   1995-12-22T09:05:02 = ဒီ
  -0010-09-15T04:44:23 = စက်

=head3 MMMd (MMM d)

   2008-02-05T18:30:30 = ဖေ 5
   1995-12-22T09:05:02 = ဒီ 22
  -0010-09-15T04:44:23 = စက် 15

=head3 MMMEd (E MMM d)

   2008-02-05T18:30:30 = ဂါ ဖေ 5
   1995-12-22T09:05:02 = ကြာ ဒီ 22
  -0010-09-15T04:44:23 = နေ စက် 15

=head3 MMMMd (MMMM d)

   2008-02-05T18:30:30 = ဖေဖော်ဝါရီ 5
   1995-12-22T09:05:02 = ဒီဇင်ဘာ 22
  -0010-09-15T04:44:23 = စက်တင်ဘာ 15

=head3 MMMMEd (E MMMM d)

   2008-02-05T18:30:30 = ဂါ ဖေဖော်ဝါရီ 5
   1995-12-22T09:05:02 = ကြာ ဒီဇင်ဘာ 22
  -0010-09-15T04:44:23 = နေ စက်တင်ဘာ 15

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (yyyy-M)

   2008-02-05T18:30:30 = 2008-2
   1995-12-22T09:05:02 = 1995-12
  -0010-09-15T04:44:23 = -010-9

=head3 yMEd (EEE, yyyy-M-d)

   2008-02-05T18:30:30 = ဂါ, 2008-2-5
   1995-12-22T09:05:02 = ကြာ, 1995-12-22
  -0010-09-15T04:44:23 = နေ, -010-9-15

=head3 yMMM (y MMM)

   2008-02-05T18:30:30 = 2008 ဖေ
   1995-12-22T09:05:02 = 1995 ဒီ
  -0010-09-15T04:44:23 = -10 စက်

=head3 yMMMEd (EEE, y MMM d)

   2008-02-05T18:30:30 = ဂါ, 2008 ဖေ 5
   1995-12-22T09:05:02 = ကြာ, 1995 ဒီ 22
  -0010-09-15T04:44:23 = နေ, -10 စက် 15

=head3 yMMMM (y MMMM)

   2008-02-05T18:30:30 = 2008 ဖေဖော်ဝါရီ
   1995-12-22T09:05:02 = 1995 ဒီဇင်ဘာ
  -0010-09-15T04:44:23 = -10 စက်တင်ဘာ

=head3 yQ (yyyy Q)

   2008-02-05T18:30:30 = 2008 1
   1995-12-22T09:05:02 = 1995 4
  -0010-09-15T04:44:23 = -010 3

=head3 yQQQ (y QQQ)

   2008-02-05T18:30:30 = 2008 ပ-စိတ်
   1995-12-22T09:05:02 = 1995 စ-စိတ်
  -0010-09-15T04:44:23 = -10 တ-စိတ်

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

တနင်္လာ


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
