###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file be.xml
# The source file version number was 1.93, generated on
# 2009/06/15 03:46:25.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::be;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "да\ палудня", "пасля\ палудня" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\,\ d\ MMMM\ y";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\ MMMM\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "d\.M\.yyyy";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "d\.M\.yy";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "пн", "аў", "ср", "чц", "пт", "сб", "нд" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "панядзелак", "аўторак", "серада", "чацвер", "пятніца", "субота", "нядзеля" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "п", "а", "с", "ч", "п", "с", "н" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "да\ н\.е\.", "н\.е\." ];
    sub era_abbreviated { return $era_abbreviated }
}
{
    my $era_narrow = [ "да\ н\.э\.", "н\.э\." ];
    sub era_narrow { return $era_narrow }
}
{
    my $era_wide = [ "да\ н\.э\.", "н\.э\." ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "сту", "лют", "сак", "кра", "май", "чэр", "ліп", "жні", "вер", "кас", "ліс", "сне" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "студзень", "люты", "сакавік", "красавік", "май", "чэрвень", "ліпень", "жнівень", "верасень", "кастрычнік", "лістапад", "снежань" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "с", "л", "с", "к", "м", "ч", "л", "ж", "в", "к", "л", "с" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "1\-шы\ кв\.", "2\-гі\ кв\.", "3\-ці\ кв\.", "4\-ты\ кв\." ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "1\-шы\ квартал", "2\-гі\ квартал", "3\-ці\ квартал", "4\-ты\ квартал" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "HH\.mm\.ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\.mm\.ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\.mm\.ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\.mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_Hm = "H\.mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_Hms = "H\.mm\.ss";
    sub _format_for_Hms { return $_format_for_Hms }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "E\,\ d\ MMM";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "E\,\ d\ MMM";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "MMMM\ d\,\ EEEE";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "MMMM\ d";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "d\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_Md = "d\.M";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_hm = "h\.mm\ a";
    sub _format_for_hm { return $_format_for_hm }
}

{
    my $_format_for_hms = "h\.mm\.ss\ a";
    sub _format_for_hms { return $_format_for_hms }
}

{
    my $_format_for_ms = "mm\:ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "MM\/yyyy";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "EEE\,\ dd\/MM\/yyyy";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "MMM\ y";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "EEE\,\ d\ MMM\ y";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "MMMM\ y";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yQ = "Q\ \'кв\'\.\ y";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "QQQ\ y";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyyM = "MM\/yyyy";
    sub _format_for_yyyyM { return $_format_for_yyyyM }
}

{
    my $_format_for_yyyyMMMM = "MMMM\ y";
    sub _format_for_yyyyMMMM { return $_format_for_yyyyMMMM }
}

{
    my $_available_formats =
        {
          "Hm" => "H\.mm",
          "Hms" => "H\.mm\.ss",
          "M" => "L",
          "MEd" => "E\,\ d\ MMM",
          "MMM" => "LLL",
          "MMMEd" => "E\,\ d\ MMM",
          "MMMMEd" => "MMMM\ d\,\ EEEE",
          "MMMMd" => "MMMM\ d",
          "MMMd" => "d\ MMM",
          "Md" => "d\.M",
          "d" => "d",
          "hm" => "h\.mm\ a",
          "hms" => "h\.mm\.ss\ a",
          "ms" => "mm\:ss",
          "y" => "y",
          "yM" => "MM\/yyyy",
          "yMEd" => "EEE\,\ dd\/MM\/yyyy",
          "yMMM" => "MMM\ y",
          "yMMMEd" => "EEE\,\ d\ MMM\ y",
          "yMMMM" => "MMMM\ y",
          "yQ" => "Q\ \'кв\'\.\ y",
          "yQQQ" => "QQQ\ y",
          "yyQ" => "Q\ yy",
          "yyyyM" => "MM\/yyyy",
          "yyyyMMMM" => "MMMM\ y"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::be

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'be' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Belarusian.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  панядзелак
  аўторак
  серада
  чацвер
  пятніца
  субота
  нядзеля

=head3 Abbreviated (format)

  пн
  аў
  ср
  чц
  пт
  сб
  нд

=head3 Narrow (format)

  п
  а
  с
  ч
  п
  с
  н

=head3 Wide (stand-alone)

  панядзелак
  аўторак
  серада
  чацвер
  пятніца
  субота
  нядзеля

=head3 Abbreviated (stand-alone)

  пн
  аў
  ср
  чц
  пт
  сб
  нд

=head3 Narrow (stand-alone)

  п
  а
  с
  ч
  п
  с
  н

=head2 Months

=head3 Wide (format)

  студзень
  люты
  сакавік
  красавік
  май
  чэрвень
  ліпень
  жнівень
  верасень
  кастрычнік
  лістапад
  снежань

=head3 Abbreviated (format)

  сту
  лют
  сак
  кра
  май
  чэр
  ліп
  жні
  вер
  кас
  ліс
  сне

=head3 Narrow (format)

  с
  л
  с
  к
  м
  ч
  л
  ж
  в
  к
  л
  с

=head3 Wide (stand-alone)

  студзень
  люты
  сакавік
  красавік
  май
  чэрвень
  ліпень
  жнівень
  верасень
  кастрычнік
  лістапад
  снежань

=head3 Abbreviated (stand-alone)

  сту
  лют
  сак
  кра
  май
  чэр
  ліп
  жні
  вер
  кас
  ліс
  сне

=head3 Narrow (stand-alone)

  с
  л
  с
  к
  м
  ч
  л
  ж
  в
  к
  л
  с

=head2 Quarters

=head3 Wide (format)

  1-шы квартал
  2-гі квартал
  3-ці квартал
  4-ты квартал

=head3 Abbreviated (format)

  1-шы кв.
  2-гі кв.
  3-ці кв.
  4-ты кв.

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  1-шы квартал
  2-гі квартал
  3-ці квартал
  4-ты квартал

=head3 Abbreviated (stand-alone)

  1-шы кв.
  2-гі кв.
  3-ці кв.
  4-ты кв.

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  да н.э.
  н.э.

=head3 Abbreviated

  да н.е.
  н.е.

=head3 Narrow

  да н.э.
  н.э.

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = аўторак, 5 люты 2008
   1995-12-22T09:05:02 = пятніца, 22 снежань 1995
  -0010-09-15T04:44:23 = субота, 15 верасень -10

=head3 Long

   2008-02-05T18:30:30 = 5 люты 2008
   1995-12-22T09:05:02 = 22 снежань 1995
  -0010-09-15T04:44:23 = 15 верасень -10

=head3 Medium

   2008-02-05T18:30:30 = 5.2.2008
   1995-12-22T09:05:02 = 22.12.1995
  -0010-09-15T04:44:23 = 15.9.-010

=head3 Short

   2008-02-05T18:30:30 = 5.2.08
   1995-12-22T09:05:02 = 22.12.95
  -0010-09-15T04:44:23 = 15.9.-10

=head3 Default

   2008-02-05T18:30:30 = 5.2.2008
   1995-12-22T09:05:02 = 22.12.1995
  -0010-09-15T04:44:23 = 15.9.-010

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18.30.30 UTC
   1995-12-22T09:05:02 = 09.05.02 UTC
  -0010-09-15T04:44:23 = 04.44.23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18.30.30 UTC
   1995-12-22T09:05:02 = 09.05.02 UTC
  -0010-09-15T04:44:23 = 04.44.23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18.30.30
   1995-12-22T09:05:02 = 09.05.02
  -0010-09-15T04:44:23 = 04.44.23

=head3 Short

   2008-02-05T18:30:30 = 18.30
   1995-12-22T09:05:02 = 09.05
  -0010-09-15T04:44:23 = 04.44

=head3 Default

   2008-02-05T18:30:30 = 18.30.30
   1995-12-22T09:05:02 = 09.05.02
  -0010-09-15T04:44:23 = 04.44.23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = аўторак, 5 люты 2008 18.30.30 UTC
   1995-12-22T09:05:02 = пятніца, 22 снежань 1995 09.05.02 UTC
  -0010-09-15T04:44:23 = субота, 15 верасень -10 04.44.23 UTC

=head3 Long

   2008-02-05T18:30:30 = 5 люты 2008 18.30.30 UTC
   1995-12-22T09:05:02 = 22 снежань 1995 09.05.02 UTC
  -0010-09-15T04:44:23 = 15 верасень -10 04.44.23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 5.2.2008 18.30.30
   1995-12-22T09:05:02 = 22.12.1995 09.05.02
  -0010-09-15T04:44:23 = 15.9.-010 04.44.23

=head3 Short

   2008-02-05T18:30:30 = 5.2.08 18.30
   1995-12-22T09:05:02 = 22.12.95 09.05
  -0010-09-15T04:44:23 = 15.9.-10 04.44

=head3 Default

   2008-02-05T18:30:30 = 5.2.2008 18.30.30
   1995-12-22T09:05:02 = 22.12.1995 09.05.02
  -0010-09-15T04:44:23 = 15.9.-010 04.44.23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 аў
   1995-12-22T09:05:02 = 22 пт
  -0010-09-15T04:44:23 = 15 сб

=head3 Hm (H.mm)

   2008-02-05T18:30:30 = 18.30
   1995-12-22T09:05:02 = 9.05
  -0010-09-15T04:44:23 = 4.44

=head3 hm (h.mm a)

   2008-02-05T18:30:30 = 6.30 пасля палудня
   1995-12-22T09:05:02 = 9.05 да палудня
  -0010-09-15T04:44:23 = 4.44 да палудня

=head3 Hms (H.mm.ss)

   2008-02-05T18:30:30 = 18.30.30
   1995-12-22T09:05:02 = 9.05.02
  -0010-09-15T04:44:23 = 4.44.23

=head3 hms (h.mm.ss a)

   2008-02-05T18:30:30 = 6.30.30 пасля палудня
   1995-12-22T09:05:02 = 9.05.02 да палудня
  -0010-09-15T04:44:23 = 4.44.23 да палудня

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (d.M)

   2008-02-05T18:30:30 = 5.2
   1995-12-22T09:05:02 = 22.12
  -0010-09-15T04:44:23 = 15.9

=head3 MEd (E, d MMM)

   2008-02-05T18:30:30 = аў, 5 лют
   1995-12-22T09:05:02 = пт, 22 сне
  -0010-09-15T04:44:23 = сб, 15 вер

=head3 MMM (LLL)

   2008-02-05T18:30:30 = лют
   1995-12-22T09:05:02 = сне
  -0010-09-15T04:44:23 = вер

=head3 MMMd (d MMM)

   2008-02-05T18:30:30 = 5 лют
   1995-12-22T09:05:02 = 22 сне
  -0010-09-15T04:44:23 = 15 вер

=head3 MMMEd (E, d MMM)

   2008-02-05T18:30:30 = аў, 5 лют
   1995-12-22T09:05:02 = пт, 22 сне
  -0010-09-15T04:44:23 = сб, 15 вер

=head3 MMMMd (MMMM d)

   2008-02-05T18:30:30 = люты 5
   1995-12-22T09:05:02 = снежань 22
  -0010-09-15T04:44:23 = верасень 15

=head3 MMMMEd (MMMM d, EEEE)

   2008-02-05T18:30:30 = люты 5, аўторак
   1995-12-22T09:05:02 = снежань 22, пятніца
  -0010-09-15T04:44:23 = верасень 15, субота

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (MM/yyyy)

   2008-02-05T18:30:30 = 02/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 09/-010

=head3 yMEd (EEE, dd/MM/yyyy)

   2008-02-05T18:30:30 = аў, 05/02/2008
   1995-12-22T09:05:02 = пт, 22/12/1995
  -0010-09-15T04:44:23 = сб, 15/09/-010

=head3 yMMM (MMM y)

   2008-02-05T18:30:30 = лют 2008
   1995-12-22T09:05:02 = сне 1995
  -0010-09-15T04:44:23 = вер -10

=head3 yMMMEd (EEE, d MMM y)

   2008-02-05T18:30:30 = аў, 5 лют 2008
   1995-12-22T09:05:02 = пт, 22 сне 1995
  -0010-09-15T04:44:23 = сб, 15 вер -10

=head3 yMMMM (MMMM y)

   2008-02-05T18:30:30 = люты 2008
   1995-12-22T09:05:02 = снежань 1995
  -0010-09-15T04:44:23 = верасень -10

=head3 yQ (Q 'кв'. y)

   2008-02-05T18:30:30 = 1 кв. 2008
   1995-12-22T09:05:02 = 4 кв. 1995
  -0010-09-15T04:44:23 = 3 кв. -10

=head3 yQQQ (QQQ y)

   2008-02-05T18:30:30 = 1-шы кв. 2008
   1995-12-22T09:05:02 = 4-ты кв. 1995
  -0010-09-15T04:44:23 = 3-ці кв. -10

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyyyM (MM/yyyy)

   2008-02-05T18:30:30 = 02/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 09/-010

=head3 yyyyMMMM (MMMM y)

   2008-02-05T18:30:30 = люты 2008
   1995-12-22T09:05:02 = снежань 1995
  -0010-09-15T04:44:23 = верасень -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

панядзелак


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
