###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file fi.xml
# The source file version number was 1.137, generated on
# 2009/06/15 03:46:25.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::fi;

use strict;
use warnings;

our $VERSION = '0.46';

use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "ap\.", "ip\." ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\ d\.\ MMMM\ y";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\.\ MMMM\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "d\.M\.yyyy";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "d\.M\.yyyy";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "ma", "ti", "ke", "to", "pe", "la", "su" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "maanantaina", "tiistaina", "keskiviikkona", "torstaina", "perjantaina", "lauantaina", "sunnuntaina" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "M", "T", "K", "T", "P", "L", "S" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}
{
    my $day_stand_alone_wide = [ "maanantai", "tiistai", "keskiviikko", "torstai", "perjantai", "lauantai", "sunnuntai" ];
    sub day_stand_alone_wide { return $day_stand_alone_wide }
}
{
    my $era_abbreviated = [ "eKr\.", "jKr\." ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "ennen\ Kristuksen\ syntymää", "jälkeen\ Kristuksen\ syntymän" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "tammikuuta", "helmikuuta", "maaliskuuta", "huhtikuuta", "toukokuuta", "kesäkuuta", "heinäkuuta", "elokuuta", "syyskuuta", "lokakuuta", "marraskuuta", "joulukuuta" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "tammikuuta", "helmikuuta", "maaliskuuta", "huhtikuuta", "toukokuuta", "kesäkuuta", "heinäkuuta", "elokuuta", "syyskuuta", "lokakuuta", "marraskuuta", "joulukuuta" ];
    sub month_format_wide { return $month_format_wide }
}
{
    my $month_stand_alone_abbreviated = [ "tammi", "helmi", "maalis", "huhti", "touko", "kesä", "heinä", "elo", "syys", "loka", "marras", "joulu" ];
    sub month_stand_alone_abbreviated { return $month_stand_alone_abbreviated }
}
{
    my $month_stand_alone_narrow = [ "T", "H", "M", "H", "T", "K", "H", "E", "S", "L", "M", "J" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}
{
    my $month_stand_alone_wide = [ "tammikuu", "helmikuu", "maaliskuu", "huhtikuu", "toukokuu", "kesäkuu", "heinäkuu", "elokuu", "syyskuu", "lokakuu", "marraskuu", "joulukuu" ];
    sub month_stand_alone_wide { return $month_stand_alone_wide }
}
{
    my $quarter_format_abbreviated = [ "1\.\ nelj\.", "2\.\ nelj\.", "3\.\ nelj\.", "4\.\ nelj\." ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "1\.\ neljännes", "2\.\ neljännes", "3\.\ neljännes", "4\.\ neljännes" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "H\.mm\.ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "H\.mm\.ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "H\.mm\.ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "H\.mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_EEEd = "EEE\ d\.";
    sub _format_for_EEEd { return $_format_for_EEEd }
}

{
    my $_format_for_HHmmss = "HH\.mm\.ss";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_Hm = "H\.mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "E\ d\.M\.";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "E\ d\.\ MMM";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "E\ d\.\ MMMM";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "d\.\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "d\.\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_Md = "d\.M\.";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_hm = "h\.mm\ a";
    sub _format_for_hm { return $_format_for_hm }
}

{
    my $_format_for_hms = "h\.mm\.ss\ a";
    sub _format_for_hms { return $_format_for_hms }
}

{
    my $_format_for_ms = "mm\.ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "L\.yyyy";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "EEE\ d\.M\.yyyy";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "LLL\ y";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "EEE\ d\.\ MMM\ y";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "LLLL\ y";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yMMMMccccd = "cccc\,\ d\.\ MMMM\ y";
    sub _format_for_yMMMMccccd { return $_format_for_yMMMMccccd }
}

{
    my $_format_for_yQ = "Q\/yyyy";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "QQQ\ y";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyMM = "M\/yy";
    sub _format_for_yyMM { return $_format_for_yyMM }
}

{
    my $_format_for_yyMMM = "MMM\ yy";
    sub _format_for_yyMMM { return $_format_for_yyMMM }
}

{
    my $_format_for_yyQ = "Q\/yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyyM = "M\/yyyy";
    sub _format_for_yyyyM { return $_format_for_yyyyM }
}

{
    my $_format_for_yyyyMEEEd = "EEE\ d\.M\.yyyy";
    sub _format_for_yyyyMEEEd { return $_format_for_yyyyMEEEd }
}

{
    my $_format_for_yyyyMMMM = "LLLL\ y";
    sub _format_for_yyyyMMMM { return $_format_for_yyyyMMMM }
}

{
    my $_format_for_yyyyQQQQ = "QQQQ\ y";
    sub _format_for_yyyyQQQQ { return $_format_for_yyyyQQQQ }
}

{
    my $_available_formats =
        {
          "EEEd" => "EEE\ d\.",
          "HHmmss" => "HH\.mm\.ss",
          "Hm" => "H\.mm",
          "M" => "L",
          "MEd" => "E\ d\.M\.",
          "MMM" => "LLL",
          "MMMEd" => "E\ d\.\ MMM",
          "MMMMEd" => "E\ d\.\ MMMM",
          "MMMMd" => "d\.\ MMMM",
          "MMMd" => "d\.\ MMM",
          "Md" => "d\.M\.",
          "d" => "d",
          "hm" => "h\.mm\ a",
          "hms" => "h\.mm\.ss\ a",
          "ms" => "mm\.ss",
          "y" => "y",
          "yM" => "L\.yyyy",
          "yMEd" => "EEE\ d\.M\.yyyy",
          "yMMM" => "LLL\ y",
          "yMMMEd" => "EEE\ d\.\ MMM\ y",
          "yMMMM" => "LLLL\ y",
          "yMMMMccccd" => "cccc\,\ d\.\ MMMM\ y",
          "yQ" => "Q\/yyyy",
          "yQQQ" => "QQQ\ y",
          "yyMM" => "M\/yy",
          "yyMMM" => "MMM\ yy",
          "yyQ" => "Q\/yy",
          "yyyyM" => "M\/yyyy",
          "yyyyMEEEd" => "EEE\ d\.M\.yyyy",
          "yyyyMMMM" => "LLLL\ y",
          "yyyyQQQQ" => "QQQQ\ y"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::fi

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'fi' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Finnish.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  maanantaina
  tiistaina
  keskiviikkona
  torstaina
  perjantaina
  lauantaina
  sunnuntaina

=head3 Abbreviated (format)

  ma
  ti
  ke
  to
  pe
  la
  su

=head3 Narrow (format)

  M
  T
  K
  T
  P
  L
  S

=head3 Wide (stand-alone)

  maanantai
  tiistai
  keskiviikko
  torstai
  perjantai
  lauantai
  sunnuntai

=head3 Abbreviated (stand-alone)

  ma
  ti
  ke
  to
  pe
  la
  su

=head3 Narrow (stand-alone)

  M
  T
  K
  T
  P
  L
  S

=head2 Months

=head3 Wide (format)

  tammikuuta
  helmikuuta
  maaliskuuta
  huhtikuuta
  toukokuuta
  kesäkuuta
  heinäkuuta
  elokuuta
  syyskuuta
  lokakuuta
  marraskuuta
  joulukuuta

=head3 Abbreviated (format)

  tammikuuta
  helmikuuta
  maaliskuuta
  huhtikuuta
  toukokuuta
  kesäkuuta
  heinäkuuta
  elokuuta
  syyskuuta
  lokakuuta
  marraskuuta
  joulukuuta

=head3 Narrow (format)

  T
  H
  M
  H
  T
  K
  H
  E
  S
  L
  M
  J

=head3 Wide (stand-alone)

  tammikuu
  helmikuu
  maaliskuu
  huhtikuu
  toukokuu
  kesäkuu
  heinäkuu
  elokuu
  syyskuu
  lokakuu
  marraskuu
  joulukuu

=head3 Abbreviated (stand-alone)

  tammi
  helmi
  maalis
  huhti
  touko
  kesä
  heinä
  elo
  syys
  loka
  marras
  joulu

=head3 Narrow (stand-alone)

  T
  H
  M
  H
  T
  K
  H
  E
  S
  L
  M
  J

=head2 Quarters

=head3 Wide (format)

  1. neljännes
  2. neljännes
  3. neljännes
  4. neljännes

=head3 Abbreviated (format)

  1. nelj.
  2. nelj.
  3. nelj.
  4. nelj.

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  1. neljännes
  2. neljännes
  3. neljännes
  4. neljännes

=head3 Abbreviated (stand-alone)

  1. nelj.
  2. nelj.
  3. nelj.
  4. nelj.

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  ennen Kristuksen syntymää
  jälkeen Kristuksen syntymän

=head3 Abbreviated

  eKr.
  jKr.

=head3 Narrow

  eKr.
  jKr.

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = tiistaina 5. helmikuuta 2008
   1995-12-22T09:05:02 = perjantaina 22. joulukuuta 1995
  -0010-09-15T04:44:23 = lauantaina 15. syyskuuta -10

=head3 Long

   2008-02-05T18:30:30 = 5. helmikuuta 2008
   1995-12-22T09:05:02 = 22. joulukuuta 1995
  -0010-09-15T04:44:23 = 15. syyskuuta -10

=head3 Medium

   2008-02-05T18:30:30 = 5.2.2008
   1995-12-22T09:05:02 = 22.12.1995
  -0010-09-15T04:44:23 = 15.9.-010

=head3 Short

   2008-02-05T18:30:30 = 5.2.2008
   1995-12-22T09:05:02 = 22.12.1995
  -0010-09-15T04:44:23 = 15.9.-010

=head3 Default

   2008-02-05T18:30:30 = 5.2.2008
   1995-12-22T09:05:02 = 22.12.1995
  -0010-09-15T04:44:23 = 15.9.-010

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18.30.30 UTC
   1995-12-22T09:05:02 = 9.05.02 UTC
  -0010-09-15T04:44:23 = 4.44.23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18.30.30 UTC
   1995-12-22T09:05:02 = 9.05.02 UTC
  -0010-09-15T04:44:23 = 4.44.23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18.30.30
   1995-12-22T09:05:02 = 9.05.02
  -0010-09-15T04:44:23 = 4.44.23

=head3 Short

   2008-02-05T18:30:30 = 18.30
   1995-12-22T09:05:02 = 9.05
  -0010-09-15T04:44:23 = 4.44

=head3 Default

   2008-02-05T18:30:30 = 18.30.30
   1995-12-22T09:05:02 = 9.05.02
  -0010-09-15T04:44:23 = 4.44.23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = tiistaina 5. helmikuuta 2008 18.30.30 UTC
   1995-12-22T09:05:02 = perjantaina 22. joulukuuta 1995 9.05.02 UTC
  -0010-09-15T04:44:23 = lauantaina 15. syyskuuta -10 4.44.23 UTC

=head3 Long

   2008-02-05T18:30:30 = 5. helmikuuta 2008 18.30.30 UTC
   1995-12-22T09:05:02 = 22. joulukuuta 1995 9.05.02 UTC
  -0010-09-15T04:44:23 = 15. syyskuuta -10 4.44.23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 5.2.2008 18.30.30
   1995-12-22T09:05:02 = 22.12.1995 9.05.02
  -0010-09-15T04:44:23 = 15.9.-010 4.44.23

=head3 Short

   2008-02-05T18:30:30 = 5.2.2008 18.30
   1995-12-22T09:05:02 = 22.12.1995 9.05
  -0010-09-15T04:44:23 = 15.9.-010 4.44

=head3 Default

   2008-02-05T18:30:30 = 5.2.2008 18.30.30
   1995-12-22T09:05:02 = 22.12.1995 9.05.02
  -0010-09-15T04:44:23 = 15.9.-010 4.44.23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (EEE d.)

   2008-02-05T18:30:30 = ti 5.
   1995-12-22T09:05:02 = pe 22.
  -0010-09-15T04:44:23 = la 15.

=head3 HHmmss (HH.mm.ss)

   2008-02-05T18:30:30 = 18.30.30
   1995-12-22T09:05:02 = 09.05.02
  -0010-09-15T04:44:23 = 04.44.23

=head3 Hm (H.mm)

   2008-02-05T18:30:30 = 18.30
   1995-12-22T09:05:02 = 9.05
  -0010-09-15T04:44:23 = 4.44

=head3 hm (h.mm a)

   2008-02-05T18:30:30 = 6.30 ip.
   1995-12-22T09:05:02 = 9.05 ap.
  -0010-09-15T04:44:23 = 4.44 ap.

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h.mm.ss a)

   2008-02-05T18:30:30 = 6.30.30 ip.
   1995-12-22T09:05:02 = 9.05.02 ap.
  -0010-09-15T04:44:23 = 4.44.23 ap.

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (d.M.)

   2008-02-05T18:30:30 = 5.2.
   1995-12-22T09:05:02 = 22.12.
  -0010-09-15T04:44:23 = 15.9.

=head3 MEd (E d.M.)

   2008-02-05T18:30:30 = ti 5.2.
   1995-12-22T09:05:02 = pe 22.12.
  -0010-09-15T04:44:23 = la 15.9.

=head3 MMM (LLL)

   2008-02-05T18:30:30 = helmi
   1995-12-22T09:05:02 = joulu
  -0010-09-15T04:44:23 = syys

=head3 MMMd (d. MMM)

   2008-02-05T18:30:30 = 5. helmikuuta
   1995-12-22T09:05:02 = 22. joulukuuta
  -0010-09-15T04:44:23 = 15. syyskuuta

=head3 MMMEd (E d. MMM)

   2008-02-05T18:30:30 = ti 5. helmikuuta
   1995-12-22T09:05:02 = pe 22. joulukuuta
  -0010-09-15T04:44:23 = la 15. syyskuuta

=head3 MMMMd (d. MMMM)

   2008-02-05T18:30:30 = 5. helmikuuta
   1995-12-22T09:05:02 = 22. joulukuuta
  -0010-09-15T04:44:23 = 15. syyskuuta

=head3 MMMMEd (E d. MMMM)

   2008-02-05T18:30:30 = ti 5. helmikuuta
   1995-12-22T09:05:02 = pe 22. joulukuuta
  -0010-09-15T04:44:23 = la 15. syyskuuta

=head3 ms (mm.ss)

   2008-02-05T18:30:30 = 30.30
   1995-12-22T09:05:02 = 05.02
  -0010-09-15T04:44:23 = 44.23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (L.yyyy)

   2008-02-05T18:30:30 = 2.2008
   1995-12-22T09:05:02 = 12.1995
  -0010-09-15T04:44:23 = 9.-010

=head3 yMEd (EEE d.M.yyyy)

   2008-02-05T18:30:30 = ti 5.2.2008
   1995-12-22T09:05:02 = pe 22.12.1995
  -0010-09-15T04:44:23 = la 15.9.-010

=head3 yMMM (LLL y)

   2008-02-05T18:30:30 = helmi 2008
   1995-12-22T09:05:02 = joulu 1995
  -0010-09-15T04:44:23 = syys -10

=head3 yMMMEd (EEE d. MMM y)

   2008-02-05T18:30:30 = ti 5. helmikuuta 2008
   1995-12-22T09:05:02 = pe 22. joulukuuta 1995
  -0010-09-15T04:44:23 = la 15. syyskuuta -10

=head3 yMMMM (LLLL y)

   2008-02-05T18:30:30 = helmikuu 2008
   1995-12-22T09:05:02 = joulukuu 1995
  -0010-09-15T04:44:23 = syyskuu -10

=head3 yMMMMccccd (cccc, d. MMMM y)

   2008-02-05T18:30:30 = tiistai, 5. helmikuuta 2008
   1995-12-22T09:05:02 = perjantai, 22. joulukuuta 1995
  -0010-09-15T04:44:23 = lauantai, 15. syyskuuta -10

=head3 yQ (Q/yyyy)

   2008-02-05T18:30:30 = 1/2008
   1995-12-22T09:05:02 = 4/1995
  -0010-09-15T04:44:23 = 3/-010

=head3 yQQQ (QQQ y)

   2008-02-05T18:30:30 = 1. nelj. 2008
   1995-12-22T09:05:02 = 4. nelj. 1995
  -0010-09-15T04:44:23 = 3. nelj. -10

=head3 yyMM (M/yy)

   2008-02-05T18:30:30 = 2/08
   1995-12-22T09:05:02 = 12/95
  -0010-09-15T04:44:23 = 9/-10

=head3 yyMMM (MMM yy)

   2008-02-05T18:30:30 = helmikuuta 08
   1995-12-22T09:05:02 = joulukuuta 95
  -0010-09-15T04:44:23 = syyskuuta -10

=head3 yyQ (Q/yy)

   2008-02-05T18:30:30 = 1/08
   1995-12-22T09:05:02 = 4/95
  -0010-09-15T04:44:23 = 3/-10

=head3 yyyyM (M/yyyy)

   2008-02-05T18:30:30 = 2/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 9/-010

=head3 yyyyMEEEd (EEE d.M.yyyy)

   2008-02-05T18:30:30 = ti 5.2.2008
   1995-12-22T09:05:02 = pe 22.12.1995
  -0010-09-15T04:44:23 = la 15.9.-010

=head3 yyyyMMMM (LLLL y)

   2008-02-05T18:30:30 = helmikuu 2008
   1995-12-22T09:05:02 = joulukuu 1995
  -0010-09-15T04:44:23 = syyskuu -10

=head3 yyyyQQQQ (QQQQ y)

   2008-02-05T18:30:30 = 1. neljännes 2008
   1995-12-22T09:05:02 = 4. neljännes 1995
  -0010-09-15T04:44:23 = 3. neljännes -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

maanantaina


=head1 SUPPORT

See L<DateTime::Locale>.

=cut
